@@ -13,7 +13,8 @@ __title__ = "nextcord"
 __author__ = "Nextcord Developers & Rapptz"
 __license__ = "MIT"
 __copyright__ = "Copyright 2015-2021 Rapptz & 2021-present Nextcord Developers"
-__version__ = "2.4.2"
+# Placeholder, modified by dynamic-versioning.
+__version__ = "3.0.0"
 
 __path__ = __import__("pkgutil").extend_path(__path__, __name__)
 
@@ -39,7 +40,7 @@ from .errors import *
 from .file import *
 from .flags import *
 from .guild import *
-from .health_check import *
+from .guild_preview import *
 from .integrations import *
 from .interactions import *
 from .invite import *
@@ -73,8 +74,10 @@ class VersionInfo(NamedTuple):
     micro: int
     releaselevel: Literal["alpha", "beta", "candidate", "final"]
     serial: int
+    metadata: str
 
 
-version_info: VersionInfo = VersionInfo(major=2, minor=4, micro=0, releaselevel="final", serial=0)
+# Placeholder, modified by dynamic-versioning.
+version_info: VersionInfo = VersionInfo(3, 0, 0, "final", 0, "None")
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
