@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import contextlib
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -75,15 +76,15 @@ if TYPE_CHECKING:
     ]
 
 
-def _transform_permissions(entry: AuditLogEntry, data: str) -> Permissions:
+def _transform_permissions(_entry: AuditLogEntry, data: str) -> Permissions:
     return Permissions(int(data))
 
 
-def _transform_color(entry: AuditLogEntry, data: int) -> Colour:
+def _transform_color(_entry: AuditLogEntry, data: int) -> Colour:
     return Colour(data)
 
 
-def _transform_snowflake(entry: AuditLogEntry, data: Snowflake) -> int:
+def _transform_snowflake(_entry: AuditLogEntry, data: Snowflake) -> int:
     return int(data)
 
 
@@ -160,7 +161,7 @@ E = TypeVar("E", bound=enums.Enum)
 
 
 def _enum_transformer(enum: Type[E]) -> Callable[[AuditLogEntry, int], E]:
-    def _transform(entry: AuditLogEntry, data: int) -> E:
+    def _transform(_entry: AuditLogEntry, data: int) -> E:
         return enums.try_enum(enum, data)
 
     return _transform
@@ -169,8 +170,7 @@ def _enum_transformer(enum: Type[E]) -> Callable[[AuditLogEntry, int], E]:
 def _transform_type(entry: AuditLogEntry, data: int) -> Union[enums.ChannelType, enums.StickerType]:
     if entry.action.name.startswith("sticker_"):
         return enums.try_enum(enums.StickerType, data)
-    else:
-        return enums.try_enum(enums.ChannelType, data)
+    return enums.try_enum(enums.ChannelType, data)
 
 
 def _list_transformer(
@@ -185,7 +185,7 @@ def _list_transformer(
 
 
 def _transform_auto_moderation_action(
-    entry: AuditLogEntry, data: Optional[AutoModerationActionPayload]
+    _entry: AuditLogEntry, data: Optional[AutoModerationActionPayload]
 ) -> Optional[AutoModerationAction]:
     if data is None:
         return None
@@ -193,7 +193,7 @@ def _transform_auto_moderation_action(
 
 
 def _transform_auto_moderation_trigger_metadata(
-    entry: AuditLogEntry, data: Optional[AutoModerationTriggerMetadataPayload]
+    _entry: AuditLogEntry, data: Optional[AutoModerationTriggerMetadataPayload]
 ) -> Optional[AutoModerationTriggerMetadata]:
     if data is None:
         return None
@@ -222,11 +222,9 @@ class AuditLogDiff:
 
     if TYPE_CHECKING:
 
-        def __getattr__(self, item: str) -> Any:
-            ...
+        def __getattr__(self, item: str) -> Any: ...
 
-        def __setattr__(self, key: str, value: Any) -> Any:
-            ...
+        def __setattr__(self, key: str, value: Any) -> Any: ...
 
 
 Transformer = Callable[["AuditLogEntry", Any], Any]
@@ -287,7 +285,7 @@ class AuditLogChanges:
             if attr == "$add":
                 self._handle_role(self.before, self.after, entry, elem["new_value"])  # type: ignore
                 continue
-            elif attr == "$remove":
+            if attr == "$remove":
                 self._handle_role(self.after, self.before, entry, elem["new_value"])  # type: ignore
                 continue
 
@@ -340,7 +338,7 @@ class AuditLogChanges:
         elem: List[RolePayload],
     ) -> None:
         if not hasattr(first, "roles"):
-            setattr(first, "roles", [])
+            first.roles = []
 
         data = []
         g: Guild = entry.guild
@@ -355,7 +353,7 @@ class AuditLogChanges:
 
             data.append(role)
 
-        setattr(second, "roles", data)
+        second.roles = data
 
 
 class _AuditLogProxyMemberPrune:
@@ -411,6 +409,8 @@ class AuditLogEntry(Hashable):
 
     Attributes
     ----------
+    guild: :class:`Guild`
+        The guild to which the audit log belongs.
     action: :class:`AuditLogAction`
         The action that was done.
     user: :class:`abc.User`
@@ -418,17 +418,15 @@ class AuditLogEntry(Hashable):
         then it's a :class:`User`.
     id: :class:`int`
         The entry ID.
-    target: Any
-        The target that got changed. The exact type of this depends on
-        the action being done.
     reason: Optional[:class:`str`]
         The reason this action was done.
     extra: Any
         Extra information that this entry has that might be useful.
-        For most actions, this is ``None``. However in some cases it
+        For most actions, this is ``None``. However, in some cases it
         contains extra information. See :class:`AuditLogAction` for
         which actions have this field filled out.
     """
+
     extra: Union[
         _AuditLogProxyMemberPrune,
         _AuditLogProxyMemberMoveOrMessageDelete,
@@ -462,9 +460,12 @@ class AuditLogEntry(Hashable):
 
         # this key is technically not usually present
         self.reason = data.get("reason")
-        self.extra = data.get("options")  # type: ignore
+        self.extra = data.get("options", {})  # type: ignore
         # I gave up trying to fix this
 
+        elems: Dict[str, Any] = {}
+        channel_id = int(self.extra["channel_id"]) if self.extra.get("channel_id", None) else None
+
         if isinstance(self.action, enums.AuditLogAction) and self.extra:
             if self.action is enums.AuditLogAction.member_prune:
                 # member prune has two keys with useful information
@@ -475,26 +476,19 @@ class AuditLogEntry(Hashable):
                 self.action is enums.AuditLogAction.member_move
                 or self.action is enums.AuditLogAction.message_delete
             ):
-                channel_id = int(self.extra["channel_id"])
                 elems = {
                     "count": int(self.extra["count"]),
-                    "channel": self.guild.get_channel(channel_id) or Object(id=channel_id),
                 }
-                self.extra = type("_AuditLogProxy", (), elems)()  # type: ignore
             elif self.action is enums.AuditLogAction.member_disconnect:
                 # The member disconnect action has a dict with some information
                 elems = {
                     "count": int(self.extra["count"]),
                 }
-                self.extra = type("_AuditLogProxy", (), elems)()  # type: ignore
             elif self.action.name.endswith("pin"):
                 # the pin actions have a dict with some information
-                channel_id = int(self.extra["channel_id"])
                 elems = {
-                    "channel": self.guild.get_channel(channel_id) or Object(id=channel_id),
                     "message_id": int(self.extra["message_id"]),
                 }
-                self.extra = type("_AuditLogProxy", (), elems)()  # type: ignore
             elif self.action.name.startswith("overwrite_"):
                 # the overwrite_ actions have a dict with some information
                 instance_id = int(self.extra["id"])
@@ -510,24 +504,25 @@ class AuditLogEntry(Hashable):
             elif self.action.name.startswith("stage_instance"):
                 channel_id = int(self.extra["channel_id"])
                 elems = {"channel": self.guild.get_channel(channel_id) or Object(id=channel_id)}
-                self.extra = type("_AuditLogProxy", (), elems)()  # type: ignore
             elif (
                 self.action is enums.AuditLogAction.auto_moderation_block_message
                 or self.action is enums.AuditLogAction.auto_moderation_flag_to_channel
                 or self.action is enums.AuditLogAction.auto_moderation_user_communication_disabled
             ):
-                channel_id = int(self.extra["channel_id"])
                 elems = {
-                    "channel": (
-                        self.guild.get_channel_or_thread(channel_id) or Object(id=channel_id)
-                    ),
                     "rule_name": self.extra["auto_moderation_rule_name"],
                     "rule_trigger_type": enums.try_enum(
                         enums.AutoModerationTriggerType,
                         int(self.extra["auto_moderation_rule_trigger_type"]),
                     ),
                 }
-                self.extra = type("_AuditLogProxy", (), elems)()  # type: ignore
+
+        # this just gets automatically filled in if present, this way prevents crashes if channel_id is None
+        if channel_id and self.action:
+            elems["channel"] = self.guild.get_channel_or_thread(channel_id) or Object(id=channel_id)
+
+        if type(self.extra) is dict:
+            self.extra = type("_AuditLogProxy", (), elems)()  # type: ignore
 
         # this key is not present when the above is present, typically.
         # It's a list of { new_value: a, old_value: b, key: c }
@@ -552,6 +547,9 @@ class AuditLogEntry(Hashable):
 
     @utils.cached_property
     def target(self) -> AuditTarget:
+        """Any: The target that got changed.
+        The exact type of this depends on the action being done.
+        """
         try:
             converter = getattr(self, "_convert_target_" + str(self.action.target_type))
         except AttributeError:
@@ -610,10 +608,9 @@ class AuditLogEntry(Hashable):
         }
 
         obj = Invite(state=self._state, data=fake_payload, guild=self.guild, channel=changeset.channel)  # type: ignore
-        try:
+        with contextlib.suppress(AttributeError):
             obj.inviter = changeset.inviter
-        except AttributeError:
-            pass
+
         return obj
 
     def _convert_target_emoji(self, target_id: int) -> Union[Emoji, Object]:
