@@ -2,7 +2,9 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, NamedTuple, Optional
+from typing import TYPE_CHECKING, List, NamedTuple, Optional
+
+from .object import Object
 
 __all__ = ("BanEntry",)
 
@@ -13,3 +15,8 @@ if TYPE_CHECKING:
 class BanEntry(NamedTuple):
     reason: Optional[str]
     user: "User"
+
+
+class BulkBan(NamedTuple):
+    banned_users: List[Object]
+    failed_users: List[Object]
