@@ -64,7 +64,7 @@ class Component:
         The type of component.
     """
 
-    __slots__: Tuple[str, ...] = ("type",)
+    __slots__: Tuple[str, ...] = ()
 
     __repr_info__: ClassVar[Tuple[str, ...]]
     type: ComponentType
@@ -106,7 +106,7 @@ class ActionRow(Component):
         The children components that this holds, if any.
     """
 
-    __slots__: Tuple[str, ...] = ("children",)
+    __slots__: Tuple[str, ...] = ("type", "children")
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
@@ -151,6 +151,7 @@ class Button(Component):
     """
 
     __slots__: Tuple[str, ...] = (
+        "type",
         "style",
         "custom_id",
         "url",
@@ -279,12 +280,12 @@ class StringSelectMenu(SelectMenuBase):
     """
 
     __slots__: Tuple[str, ...] = ("options",)
-
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
+    type: Literal[ComponentType.select] = ComponentType.select
+
     def __init__(self, data: SelectMenuPayload) -> None:
         super().__init__(data)
-        self.type = ComponentType.select
         self.options: List[SelectOption] = [
             SelectOption.from_dict(option) for option in data.get("options", [])
         ]
@@ -332,12 +333,12 @@ class UserSelectMenu(SelectMenuBase):
     """
 
     __slots__: Tuple[str, ...] = ()
-
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
+    type: Literal[ComponentType.user_select] = ComponentType.user_select
+
     def __init__(self, data: UserSelectMenuPayload) -> None:
         super().__init__(data)
-        self.type = ComponentType.user_select
 
     def to_dict(self) -> UserSelectMenuPayload:
         payload: UserSelectMenuPayload = {"type": self.type.value, **super().to_dict()}
@@ -375,12 +376,12 @@ class RoleSelectMenu(SelectMenuBase):
     """
 
     __slots__: Tuple[str, ...] = ()
-
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
+    type: Literal[ComponentType.role_select] = ComponentType.role_select
+
     def __init__(self, data: RoleSelectMenuPayload) -> None:
         super().__init__(data)
-        self.type = ComponentType.role_select
 
     def to_dict(self) -> RoleSelectMenuPayload:
         payload: RoleSelectMenuPayload = {"type": self.type.value, **super().to_dict()}
@@ -418,12 +419,12 @@ class MentionableSelectMenu(SelectMenuBase):
     """
 
     __slots__: Tuple[str, ...] = ()
-
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
+    type: Literal[ComponentType.mentionable_select] = ComponentType.mentionable_select
+
     def __init__(self, data: MentionableSelectMenuPayload) -> None:
         super().__init__(data)
-        self.type = ComponentType.mentionable_select
 
     def to_dict(self) -> MentionableSelectMenuPayload:
         payload: MentionableSelectMenuPayload = {"type": self.type.value, **super().to_dict()}
@@ -463,12 +464,12 @@ class ChannelSelectMenu(SelectMenuBase):
     """
 
     __slots__: Tuple[str, ...] = ("channel_types",)
-
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
+    type: Literal[ComponentType.channel_select] = ComponentType.channel_select
+
     def __init__(self, data: ChannelSelectMenuPayload) -> None:
         super().__init__(data)
-        self.type = ComponentType.channel_select
         self.channel_types: List[ChannelType] = [
             ChannelType(t) for t in data.get("channel_types", [])
         ]
@@ -547,10 +548,7 @@ class SelectOption:
         )
 
     def __str__(self) -> str:
-        if self.emoji:
-            base = f"{self.emoji} {self.label}"
-        else:
-            base = self.label
+        base = f"{self.emoji} {self.label}" if self.emoji else self.label
 
         if self.description:
             return f"{base}\n{self.description}"
@@ -589,6 +587,7 @@ class SelectOption:
 
 class TextInput(Component):
     __slots__: Tuple[str, ...] = (
+        "type",
         "style",
         "custom_id",
         "label",
@@ -645,12 +644,11 @@ def _component_factory(data: ComponentPayload) -> Component:
     component_type = data["type"]
     if component_type == 1:
         return ActionRow(data)
-    elif component_type == 2:
+    if component_type == 2:
         return Button(data)  # type: ignore
-    elif component_type == 3:
+    if component_type == 3:
         return SelectMenu(data)  # type: ignore
-    elif component_type == 4:
+    if component_type == 4:
         return TextInput(data)  # type: ignore
-    else:
-        as_enum = try_enum(ComponentType, component_type)
-        return Component._raw_construct(type=as_enum)
+    as_enum = try_enum(ComponentType, component_type)
+    return Component._raw_construct(type=as_enum)
