@@ -2,8 +2,8 @@
 
 from __future__ import annotations
 
+import contextlib
 import datetime
-import warnings
 from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Optional, Protocol, Union
 
 from . import utils
@@ -14,9 +14,6 @@ if TYPE_CHECKING:
 
 __all__ = ("Embed",)
 
-# Backwards compatibility
-EmptyEmbed = None
-
 
 class EmbedProxy:
     def __init__(self, layer: Dict[str, Any]) -> None:
@@ -96,6 +93,9 @@ class Embed:
             and is typed as ``Optional[...]`` over ``Embed.Empty``.
             This also means that you can no longer use ``len()`` on an empty field.
 
+    .. versionchanged:: 3.0
+        ``Embed.Empty`` has been removed in favor of ``None``.
+
     Attributes
     ----------
     title: :class:`str`
@@ -143,10 +143,10 @@ class Embed:
         *,
         colour: Optional[Union[int, Colour]] = None,
         color: Optional[Union[int, Colour]] = None,
-        title: Optional[Any] = None,
+        title: Optional[str] = None,
         type: EmbedType = "rich",
-        url: Optional[Any] = None,
-        description: Optional[Any] = None,
+        url: Optional[str] = None,
+        description: Optional[str] = None,
         timestamp: Optional[datetime.datetime] = None,
     ) -> None:
         self.colour = colour if colour is not None else color
@@ -156,27 +156,17 @@ class Embed:
         self.description = description
 
         if self.title is not None:
-            self.title = str(self.title)
+            self.title = self.title
 
         if self.description is not None:
-            self.description = str(self.description)
+            self.description = self.description
 
         if self.url is not None:
-            self.url = str(self.url)
+            self.url = self.url
 
         if timestamp:
             self.timestamp = timestamp
 
-    # backwards compatibility
-    @property
-    def Empty(self) -> None:
-        warnings.warn(
-            "Empty is deprecated and will be removed in a future version. Use None instead.",
-            FutureWarning,
-            stacklevel=2,
-        )
-        return None
-
     @classmethod
     def from_dict(cls, data: Mapping[str, Any]) -> Self:
         """Converts a :class:`dict` to a :class:`Embed` provided it is in the
@@ -214,15 +204,11 @@ class Embed:
 
         # try to fill in the more rich fields
 
-        try:
+        with contextlib.suppress(KeyError):
             self._colour = Colour(value=data["color"])
-        except KeyError:
-            pass
 
-        try:
+        with contextlib.suppress(KeyError):
             self._timestamp = utils.parse_time(data["timestamp"])
-        except KeyError:
-            pass
 
         for attr in ("thumbnail", "video", "provider", "author", "fields", "image", "footer"):
             try:
@@ -321,7 +307,12 @@ class Embed:
         """
         return EmbedProxy(getattr(self, "_footer", {}))  # type: ignore
 
-    def set_footer(self, *, text: Optional[Any] = None, icon_url: Optional[Any] = None) -> Self:
+    def set_footer(
+        self,
+        *,
+        text: Optional[str] = None,
+        icon_url: Optional[str] = None,
+    ) -> Self:
         """Sets the footer for the embed content.
 
         This function returns the class instance to allow for fluent-style
@@ -337,10 +328,10 @@ class Embed:
 
         self._footer = {}
         if text is not None:
-            self._footer["text"] = str(text)
+            self._footer["text"] = text
 
         if icon_url is not None:
-            self._footer["icon_url"] = str(icon_url)
+            self._footer["icon_url"] = icon_url
 
         return self
 
@@ -352,10 +343,8 @@ class Embed:
 
         .. versionadded:: 2.0
         """
-        try:
+        with contextlib.suppress(AttributeError):
             del self._footer
-        except AttributeError:
-            pass
 
         return self
 
@@ -374,7 +363,7 @@ class Embed:
         """
         return EmbedProxy(getattr(self, "_image", {}))  # type: ignore
 
-    def set_image(self, url: Optional[Any]) -> Self:
+    def set_image(self, url: Optional[str]) -> Self:
         """Sets the image for the embed content.
 
         This function returns the class instance to allow for fluent-style
@@ -390,13 +379,12 @@ class Embed:
         """
 
         if url is None:
-            try:
+            with contextlib.suppress(AttributeError):
                 del self._image
-            except AttributeError:
-                pass
+
         else:
             self._image = {
-                "url": str(url),
+                "url": url,
             }
 
         return self
@@ -416,7 +404,7 @@ class Embed:
         """
         return EmbedProxy(getattr(self, "_thumbnail", {}))  # type: ignore
 
-    def set_thumbnail(self, url: Optional[Any]) -> Self:
+    def set_thumbnail(self, url: Optional[str]) -> Self:
         """Sets the thumbnail for the embed content.
 
         This function returns the class instance to allow for fluent-style
@@ -427,18 +415,17 @@ class Embed:
 
         Parameters
         ----------
-        url: :class:`str`
+        url: Optional[:class:`str`]
             The source URL for the thumbnail. Only HTTP(S) is supported.
         """
 
         if url is None:
-            try:
+            with contextlib.suppress(AttributeError):
                 del self._thumbnail
-            except AttributeError:
-                pass
+
         else:
             self._thumbnail = {
-                "url": str(url),
+                "url": url,
             }
 
         return self
@@ -480,9 +467,9 @@ class Embed:
     def set_author(
         self,
         *,
-        name: Any,
-        url: Optional[Any] = None,
-        icon_url: Optional[Any] = None,
+        name: str,
+        url: Optional[str] = None,
+        icon_url: Optional[str] = None,
     ) -> Self:
         """Sets the author for the embed content.
 
@@ -500,14 +487,14 @@ class Embed:
         """
 
         self._author = {
-            "name": str(name),
+            "name": name,
         }
 
         if url is not None:
-            self._author["url"] = str(url)
+            self._author["url"] = url
 
         if icon_url is not None:
-            self._author["icon_url"] = str(icon_url)
+            self._author["icon_url"] = icon_url
 
         return self
 
@@ -519,10 +506,8 @@ class Embed:
 
         .. versionadded:: 1.4
         """
-        try:
+        with contextlib.suppress(AttributeError):
             del self._author
-        except AttributeError:
-            pass
 
         return self
 
@@ -536,7 +521,7 @@ class Embed:
         """
         return [EmbedProxy(d) for d in getattr(self, "_fields", [])]  # type: ignore
 
-    def add_field(self, *, name: Any, value: Any, inline: bool = True) -> Self:
+    def add_field(self, *, name: str, value: str, inline: bool = True) -> Self:
         """Adds a field to the embed object.
 
         This function returns the class instance to allow for fluent-style
@@ -554,8 +539,8 @@ class Embed:
 
         field = {
             "inline": inline,
-            "name": str(name),
-            "value": str(value),
+            "name": name,
+            "value": value,
         }
 
         try:
@@ -565,7 +550,14 @@ class Embed:
 
         return self
 
-    def insert_field_at(self, index: int, *, name: Any, value: Any, inline: bool = True) -> Self:
+    def insert_field_at(
+        self,
+        index: int,
+        *,
+        name: str,
+        value: str,
+        inline: bool = True,
+    ) -> Self:
         """Inserts a field before a specified index to the embed.
 
         This function returns the class instance to allow for fluent-style
@@ -587,8 +579,8 @@ class Embed:
 
         field = {
             "inline": inline,
-            "name": str(name),
-            "value": str(value),
+            "name": name,
+            "value": value,
         }
 
         try:
@@ -630,14 +622,19 @@ class Embed:
         index: :class:`int`
             The index of the field to remove.
         """
-        try:
+        with contextlib.suppress(AttributeError, IndexError):
             del self._fields[index]
-        except (AttributeError, IndexError):
-            pass
 
         return self
 
-    def set_field_at(self, index: int, *, name: Any, value: Any, inline: bool = True) -> Self:
+    def set_field_at(
+        self,
+        index: int,
+        *,
+        name: str,
+        value: str,
+        inline: bool = True,
+    ) -> Self:
         """Modifies a field to the embed object.
 
         The index must point to a valid pre-existing field.
@@ -664,11 +661,11 @@ class Embed:
 
         try:
             field = self._fields[index]
-        except (TypeError, IndexError, AttributeError):
-            raise IndexError("field index out of range")
+        except (TypeError, IndexError, AttributeError) as e:
+            raise IndexError("field index out of range") from e
 
-        field["name"] = str(name)
-        field["value"] = str(value)
+        field["name"] = name
+        field["value"] = value
         field["inline"] = inline
         return self
 
@@ -680,7 +677,7 @@ class Embed:
         result = {
             key[1:]: getattr(self, key)
             for key in self.__slots__
-            if key[0] == '_' and hasattr(self, key)
+            if key[0] == "_" and hasattr(self, key)
         }
         # fmt: on
 
