@@ -4,7 +4,7 @@ from __future__ import annotations
 
 import asyncio
 import functools
-from typing import TYPE_CHECKING, Callable, Union
+from typing import TYPE_CHECKING, Callable, Dict, Union
 
 import nextcord
 from nextcord.application_command import (
@@ -276,7 +276,7 @@ def has_role(item: Union[int, str]) -> AC:
 
     def predicate(interaction: Interaction) -> bool:
         if interaction.guild is None:
-            raise ApplicationNoPrivateMessage()
+            raise ApplicationNoPrivateMessage
 
         # interaction.guild is None doesn't narrow interaction.user to Member
         if isinstance(item, int):
@@ -319,7 +319,7 @@ def has_any_role(*items: Union[int, str]) -> AC:
 
     def predicate(interaction: Interaction) -> bool:
         if interaction.guild is None:
-            raise ApplicationNoPrivateMessage()
+            raise ApplicationNoPrivateMessage
 
         # interaction.guild is None doesn't narrow interaction.user to Member
         getter = functools.partial(nextcord.utils.get, interaction.user.roles)  # type: ignore
@@ -360,7 +360,7 @@ def bot_has_role(item: Union[int, str]) -> AC:
 
     def predicate(interaction: Interaction) -> bool:
         if interaction.guild is None:
-            raise ApplicationNoPrivateMessage()
+            raise ApplicationNoPrivateMessage
 
         me = interaction.guild.me
         if isinstance(item, int):
@@ -401,7 +401,7 @@ def bot_has_any_role(*items: Union[str, int]) -> AC:
 
     def predicate(interaction: Interaction) -> bool:
         if interaction.guild is None:
-            raise ApplicationNoPrivateMessage()
+            raise ApplicationNoPrivateMessage
 
         getter = functools.partial(nextcord.utils.get, interaction.guild.me.roles)
         if any(
@@ -414,6 +414,16 @@ def bot_has_any_role(*items: Union[str, int]) -> AC:
     return check(predicate)
 
 
+def _permission_check_wrapper(predicate: ApplicationCheck, name: str, perms: Dict[str, bool]) -> AC:
+    def wrapper(func) -> CheckWrapper:
+        callback = func.callback if isinstance(func, CallbackWrapper) else func
+
+        setattr(callback, name, perms)
+        return check(predicate)(func)  # type: ignore
+
+    return wrapper
+
+
 def has_permissions(**perms: bool) -> AC:
     """A :func:`.check` that is added that checks if the member has all of
     the permissions necessary.
@@ -456,7 +466,7 @@ def has_permissions(**perms: bool) -> AC:
         try:
             permissions = ch.permissions_for(interaction.user)  # type: ignore
         except AttributeError:
-            raise ApplicationNoPrivateMessage()
+            raise ApplicationNoPrivateMessage from None
 
         missing = [perm for perm, value in perms.items() if getattr(permissions, perm) != value]
 
@@ -465,7 +475,7 @@ def has_permissions(**perms: bool) -> AC:
 
         raise ApplicationMissingPermissions(missing)
 
-    return check(predicate)
+    return _permission_check_wrapper(predicate, "__slash_required_permissions", perms)
 
 
 def bot_has_permissions(**perms: bool) -> AC:
@@ -490,7 +500,7 @@ def bot_has_permissions(**perms: bool) -> AC:
         try:
             permissions = ch.permissions_for(me)  # type: ignore
         except AttributeError:
-            raise ApplicationNoPrivateMessage()
+            raise ApplicationNoPrivateMessage from None
 
         missing = [perm for perm, value in perms.items() if getattr(permissions, perm) != value]
 
@@ -499,7 +509,7 @@ def bot_has_permissions(**perms: bool) -> AC:
 
         raise ApplicationBotMissingPermissions(missing)
 
-    return check(predicate)
+    return _permission_check_wrapper(predicate, "__slash_required_bot_permissions", perms)
 
 
 def has_guild_permissions(**perms: bool) -> AC:
@@ -541,7 +551,7 @@ def has_guild_permissions(**perms: bool) -> AC:
 
         raise ApplicationMissingPermissions(missing)
 
-    return check(predicate)
+    return _permission_check_wrapper(predicate, "__slash_required_guild_permissions", perms)
 
 
 def bot_has_guild_permissions(**perms: bool) -> AC:
@@ -565,7 +575,7 @@ def bot_has_guild_permissions(**perms: bool) -> AC:
 
         raise ApplicationBotMissingPermissions(missing)
 
-    return check(predicate)
+    return _permission_check_wrapper(predicate, "__slash_required_bot_guild_permissions", perms)
 
 
 def dm_only() -> AC:
@@ -589,7 +599,7 @@ def dm_only() -> AC:
 
     def predicate(interaction: Interaction) -> bool:
         if interaction.guild is not None:
-            raise ApplicationPrivateMessageOnly()
+            raise ApplicationPrivateMessageOnly
         return True
 
     return check(predicate)
@@ -616,7 +626,7 @@ def guild_only() -> AC:
 
     def predicate(interaction: Interaction) -> bool:
         if interaction.guild is None:
-            raise ApplicationNoPrivateMessage()
+            raise ApplicationNoPrivateMessage
         return True
 
     return check(predicate)
@@ -649,7 +659,7 @@ def is_owner() -> AC:
 
     async def predicate(interaction: Interaction) -> bool:
         if not hasattr(interaction.client, "is_owner"):
-            raise ApplicationCheckForBotOnly()
+            raise ApplicationCheckForBotOnly
 
         if not await interaction.client.is_owner(interaction.user):
             raise ApplicationNotOwner("You do not own this bot.")
