@@ -5,6 +5,7 @@ from __future__ import annotations
 import asyncio
 import collections
 import collections.abc
+import contextlib
 import copy
 import importlib.util
 import inspect
@@ -49,7 +50,6 @@ if TYPE_CHECKING:
     from nextcord.flags import MemberCacheFlags
     from nextcord.mentions import AllowedMentions
     from nextcord.message import Message
-    from nextcord.types.checks import ApplicationCheck, ApplicationHook
 
     from ._types import Check, CoroFunc
 
@@ -68,7 +68,7 @@ CFT = TypeVar("CFT", bound="CoroFunc")
 CXT = TypeVar("CXT", bound="Context")
 
 
-def when_mentioned(bot: Union[Bot, AutoShardedBot], msg: Message) -> List[str]:
+def when_mentioned(bot: Union[Bot, AutoShardedBot], _msg: Message) -> List[str]:
     """A callable that implements a command prefix equivalent to being mentioned.
 
     These are meant to be passed into the :attr:`.Bot.command_prefix` attribute.
@@ -109,8 +109,7 @@ def when_mentioned_or(*prefixes: str) -> Callable[[Union[Bot, AutoShardedBot], M
 
     def inner(bot, msg):
         r = list(prefixes)
-        r = when_mentioned(bot, msg) + r
-        return r
+        return when_mentioned(bot, msg) + r
 
     return inner
 
@@ -137,13 +136,13 @@ class MissingMessageContentIntentWarning(UserWarning):
         warnings.simplefilter("ignore", commands.MissingMessageContentIntentWarning)
     """
 
-    pass
-
 
 _NonCallablePrefix = Union[str, Sequence[str]]
 
 
 class BotBase(GroupMixin):
+    extra_events: Dict[str, List[CoroFunc]]
+
     def __init__(
         self,
         command_prefix: Union[
@@ -165,8 +164,7 @@ class BotBase(GroupMixin):
             case_insensitive=case_insensitive,
         )
 
-        self.command_prefix = command_prefix if command_prefix is not MISSING else tuple()
-        self.extra_events: Dict[str, List[CoroFunc]] = {}
+        self.command_prefix = command_prefix if command_prefix is not MISSING else ()
         self.__cogs: Dict[str, Cog] = {}
         self.__extensions: Dict[str, types.ModuleType] = {}
         self._checks: List[Check] = []
@@ -213,26 +211,21 @@ class BotBase(GroupMixin):
 
     # internal helpers
 
+    # kept in since BotBase isn't a direct subclass of client and thus doesn't know
+    # about inheriting this method
     def dispatch(self, event_name: str, *args: Any, **kwargs: Any) -> None:
         # super() will resolve to Client
         super().dispatch(event_name, *args, **kwargs)  # type: ignore
-        ev = "on_" + event_name
-        for event in self.extra_events.get(ev, []):
-            self._schedule_event(event, ev, *args, **kwargs)  # type: ignore
 
     @nextcord.utils.copy_doc(nextcord.Client.close)
     async def close(self) -> None:
         for extension in tuple(self.__extensions):
-            try:
+            with contextlib.suppress(Exception):
                 self.unload_extension(extension)
-            except Exception:
-                pass
 
         for cog in tuple(self.__cogs):
-            try:
+            with contextlib.suppress(Exception):
                 self.remove_cog(cog)
-            except Exception:
-                pass
 
         await super().close()  # type: ignore
 
@@ -257,7 +250,7 @@ class BotBase(GroupMixin):
         if cog and cog.has_error_handler():
             return
 
-        print(f"Ignoring exception in command {context.command}:", file=sys.stderr)
+        print(f"Ignoring exception in command {context.command}:", file=sys.stderr)  # noqa: T201
         traceback.print_exception(
             type(exception), exception, exception.__traceback__, file=sys.stderr
         )
@@ -329,10 +322,8 @@ class BotBase(GroupMixin):
         """
         l = self._check_once if call_once else self._checks
 
-        try:
+        with contextlib.suppress(ValueError):
             l.remove(func)
-        except ValueError:
-            pass
 
     def check_once(self, func: CFT) -> CFT:
         r"""A decorator that adds a "call once" global check to the bot.
@@ -406,16 +397,16 @@ class BotBase(GroupMixin):
 
         if self.owner_id:
             return user.id == self.owner_id
-        elif self.owner_ids:
+        if self.owner_ids:
             return user.id in self.owner_ids
-        else:
-            app = await self.application_info()  # type: ignore
-            if app.team:
-                self.owner_ids = ids = {m.id for m in app.team.members}
-                return user.id in ids
-            else:
-                self.owner_id = owner_id = app.owner.id
-                return user.id == owner_id
+
+        app = await self.application_info()  # type: ignore
+        if app.team:
+            self.owner_ids = ids = {m.id for m in app.team.members}
+            return user.id in ids
+
+        self.owner_id = owner_id = app.owner.id
+        return user.id == owner_id
 
     def before_invoke(self, coro: CFT) -> CFT:
         """A decorator that registers a coroutine as a pre-invoke hook.
@@ -484,93 +475,13 @@ class BotBase(GroupMixin):
 
     # listener registration
 
+    @nextcord.utils.copy_doc(nextcord.Client.add_listener)
     def add_listener(self, func: CoroFunc, name: str = MISSING) -> None:
-        """The non decorator alternative to :meth:`.listen`.
-
-        Parameters
-        ----------
-        func: :ref:`coroutine <coroutine>`
-            The function to call.
-        name: :class:`str`
-            The name of the event to listen for. Defaults to ``func.__name__``.
-
-        Example
-        -------
-
-        .. code-block:: python3
-
-            async def on_ready(): pass
-            async def my_message(message): pass
-
-            bot.add_listener(on_ready)
-            bot.add_listener(my_message, 'on_message')
-
-        """
-        name = func.__name__ if name is MISSING else name
-
-        if not asyncio.iscoroutinefunction(func):
-            raise TypeError("Listeners must be coroutines")
-
-        if name in self.extra_events:
-            self.extra_events[name].append(func)
-        else:
-            self.extra_events[name] = [func]
+        super().add_listener(func, name)  # type: ignore
 
+    @nextcord.utils.copy_doc(nextcord.Client.remove_listener)
     def remove_listener(self, func: CoroFunc, name: str = MISSING) -> None:
-        """Removes a listener from the pool of listeners.
-
-        Parameters
-        ----------
-        func
-            The function that was used as a listener to remove.
-        name: :class:`str`
-            The name of the event we want to remove. Defaults to
-            ``func.__name__``.
-        """
-
-        name = func.__name__ if name is MISSING else name
-
-        if name in self.extra_events:
-            try:
-                self.extra_events[name].remove(func)
-            except ValueError:
-                pass
-
-    def listen(self, name: str = MISSING) -> Callable[[CFT], CFT]:
-        """A decorator that registers another function as an external
-        event listener. Basically this allows you to listen to multiple
-        events from different places e.g. such as :func:`.on_ready`
-
-        The functions being listened to must be a :ref:`coroutine <coroutine>`.
-
-        Example
-        -------
-
-        .. code-block:: python3
-
-            @bot.listen()
-            async def on_message(message):
-                print('one')
-
-            # in some other file...
-
-            @bot.listen('on_message')
-            async def my_message(message):
-                print('two')
-
-        Would print one and two in an unspecified order.
-
-        Raises
-        ------
-        TypeError
-            The function being listened to is not a coroutine.
-        """
-
-        def decorator(func: CFT) -> CFT:
-            self.add_listener(func, name)
-            return func
-
-        return decorator
+        super().remove_listener(func, name)  # type: ignore
 
     # cogs
 
@@ -600,7 +511,7 @@ class BotBase(GroupMixin):
             The cog does not inherit from :class:`.Cog`.
         CommandError
             An error happened during loading.
-        .ClientException
+        ClientException
             A cog with the same name is already loaded.
         """
 
@@ -666,7 +577,7 @@ class BotBase(GroupMixin):
 
         cog = self.__cogs.pop(name, None)
         if cog is None:
-            return
+            return None
 
         help_command = self._help_command
         if help_command and help_command.cog is cog:
@@ -695,7 +606,7 @@ class BotBase(GroupMixin):
 
         # remove all the commands from the module
         for cmd in self.all_commands.copy().values():
-            if cmd.module is not None and _is_submodule(name, cmd.module):
+            if _is_submodule(name, cmd.module):
                 if isinstance(cmd, GroupMixin):
                     cmd.recursively_remove_all_commands()
                 self.remove_command(cmd.name)
@@ -704,7 +615,7 @@ class BotBase(GroupMixin):
         for event_list in self.extra_events.copy().values():
             remove = []
             for index, event in enumerate(event_list):
-                if event.__module__ is not None and _is_submodule(name, event.__module__):
+                if _is_submodule(name, event.__module__):
                     remove.append(index)
 
             for index in reversed(remove):
@@ -712,14 +623,13 @@ class BotBase(GroupMixin):
 
     def _call_module_finalizers(self, lib: types.ModuleType, key: str) -> None:
         try:
-            func = getattr(lib, "teardown")
+            func = lib.teardown
         except AttributeError:
             pass
         else:
-            try:
+            with contextlib.suppress(Exception):
                 func(self)
-            except Exception:
-                pass
+
         finally:
             self.__extensions.pop(key, None)
             sys.modules.pop(key, None)
@@ -734,7 +644,7 @@ class BotBase(GroupMixin):
         key: str,
         extras: Optional[Dict[str, Any]] = None,
     ) -> None:
-        # precondition: key not in self.__extensions
+        # precondition - key not in self.__extensions
         lib = importlib.util.module_from_spec(spec)
         sys.modules[key] = lib
         try:
@@ -744,10 +654,10 @@ class BotBase(GroupMixin):
             raise errors.ExtensionFailed(key, e) from e
 
         try:
-            setup = getattr(lib, "setup")
+            setup = lib.setup
         except AttributeError:
             del sys.modules[key]
-            raise errors.NoEntryPointError(key)
+            raise errors.NoEntryPointError(key) from None
 
         params = inspect.signature(setup).parameters
         has_kwargs = len(params) > 1
@@ -755,14 +665,15 @@ class BotBase(GroupMixin):
         if extras is not None:
             if not has_kwargs:
                 raise errors.InvalidSetupArguments(key)
-            elif not isinstance(extras, dict):
+            if not isinstance(extras, dict):
                 raise errors.ExtensionFailed(key, TypeError("Expected 'extras' to be a dictionary"))
 
         extras = extras or {}
         try:
             if asyncio.iscoroutinefunction(setup):
                 try:
-                    asyncio.create_task(setup(self, **extras))
+                    # I don't want to deal with handling tasks with a niche feature.
+                    asyncio.create_task(setup(self, **extras))  # noqa: RUF006
                 except RuntimeError:
                     raise RuntimeError(
                         """
@@ -770,7 +681,7 @@ class BotBase(GroupMixin):
                     Please read our FAQ here:
                     https://docs.nextcord.dev/en/stable/faq.html#how-do-i-make-my-setup-function-a-coroutine-and-load-it
                     """
-                    )
+                    ) from None
             else:
                 setup(self, **extras)
         except Exception as e:
@@ -784,8 +695,8 @@ class BotBase(GroupMixin):
     def _resolve_name(self, name: str, package: Optional[str]) -> str:
         try:
             return importlib.util.resolve_name(name, package)
-        except ImportError:
-            raise errors.ExtensionNotFound(name)
+        except ImportError as e:
+            raise errors.ExtensionNotFound(name) from e
 
     def load_extension(
         self, name: str, *, package: Optional[str] = None, extras: Optional[Dict[str, Any]] = None
@@ -903,7 +814,9 @@ class BotBase(GroupMixin):
         self._remove_module_references(lib.__name__)
         self._call_module_finalizers(lib, name)
 
-    def reload_extension(self, name: str, *, package: Optional[str] = None) -> None:
+    def reload_extension(
+        self, name: str, *, package: Optional[str] = None, extras: Optional[Dict[str, Any]] = None
+    ) -> None:
         """Atomically reloads an extension.
 
         This replaces the extension with the same extension, only refreshed. This is
@@ -923,6 +836,30 @@ class BotBase(GroupMixin):
             Defaults to ``None``.
 
             .. versionadded:: 1.7
+        extras: Optional[:class:`dict`]
+            A mapping of kwargs to values to be passed to your
+            cog's ``__init__`` method as keyword arguments.
+
+            Usage ::
+
+                # main.py
+                bot.load_extension("cogs.me_cog", extras={"keyword_arg": False})
+                bot.reload_extension("cogs.me_cog", extras={"keyword_arg": True})
+
+                # cogs/me_cog.py
+                class MeCog(commands.Cog):
+                    def __init__(self, bot, keyword_arg):
+                        self.bot = bot
+                        self.keyword_arg = keyword_arg
+
+                def setup(bot, **kwargs):
+                    bot.add_cog(MeCog(bot, **kwargs))
+
+                # Alternately
+                def setup(bot, keyword_arg):
+                    bot.add_cog(MeCog(bot, keyword_arg))
+
+            .. versionadded:: v3.0
 
         Raises
         ------
@@ -936,6 +873,9 @@ class BotBase(GroupMixin):
             The extension does not have a setup function.
         ExtensionFailed
             The extension setup function had an execution error.
+        InvalidSetupArguments
+            ``reload_extension`` was given ``extras`` but the ``setup``
+            function did not take any additional arguments.
         """
 
         name = self._resolve_name(name, package)
@@ -954,7 +894,7 @@ class BotBase(GroupMixin):
             # Unload and then load the module...
             self._remove_module_references(lib.__name__)
             self._call_module_finalizers(lib, name)
-            self.load_extension(name)
+            self.load_extension(name, extras=extras)
         except Exception:
             # if the load failed, the remnants should have been
             # cleaned from the load_extension function call
@@ -1114,9 +1054,8 @@ class BotBase(GroupMixin):
             except Exception as e:
                 if stop_at_error:
                     raise e
-                else:
-                    # we print the exception instead of raising it because we want to continue loading extensions
-                    traceback.print_exception(type(e), e, e.__traceback__, file=sys.stderr)
+                # we print the exception instead of raising it because we want to continue loading extensions
+                traceback.print_exception(type(e), e, e.__traceback__, file=sys.stderr)
             else:
                 loaded_extensions.append(extension)
 
@@ -1255,7 +1194,7 @@ class BotBase(GroupMixin):
                 raise TypeError(
                     "command_prefix must be plain string, iterable of strings, or callable "
                     f"returning either of these, not {ret.__class__.__name__}"
-                )
+                ) from None
 
         return ret
 
@@ -1290,8 +1229,7 @@ class BotBase(GroupMixin):
         """
 
         view = StringView(message.content)
-        ctx: CXT = cls(prefix=None, view=view, bot=self, message=message)  # type: ignore
-        # pyright/lance has no idea how typevars work for some reason
+        ctx: CXT = cls(prefix=None, view=view, bot=self, message=message)
 
         if message.author.id == self.user.id:  # type: ignore
             return ctx
@@ -1316,7 +1254,7 @@ class BotBase(GroupMixin):
                     raise TypeError(
                         "get_prefix must return either a string or a list of string, "
                         f"not {prefix.__class__.__name__}"
-                    )
+                    ) from None
 
                 # It's possible a bad command_prefix got us here.
                 for value in prefix:
@@ -1324,7 +1262,7 @@ class BotBase(GroupMixin):
                         raise TypeError(
                             "Iterable command_prefix or list returned from get_prefix must "
                             f"contain only strings, not {value.__class__.__name__}"
-                        )
+                        ) from None
 
                 # Getting here shouldn't happen
                 raise
@@ -1429,128 +1367,6 @@ class BotBase(GroupMixin):
     async def on_message(self, message) -> None:
         await self.process_commands(message)
 
-    def add_application_command_check(self, func: ApplicationCheck) -> None:
-        """Adds a global application check to the bot.
-
-        This is the non-decorator interface to :meth:`.check`
-        and :meth:`.check_once`.
-
-        Parameters
-        ----------
-        func: Callable[[:class:`Interaction`], MaybeCoro[bool]]]
-            The function that was used as a global application check.
-        """
-
-        self._connection._application_command_checks.append(func)  # type: ignore
-
-    def remove_application_command_check(self, func: ApplicationCheck) -> None:
-        """Removes a global check from the bot.
-
-        This function is idempotent and will not raise an exception
-        if the function is not in the global checks.
-
-        Parameters
-        ----------
-        func: Callable[[:class:`Interaction`], MaybeCoro[bool]]]
-            The function to remove from the global application checks.
-        """
-
-        try:
-            self._connection._application_command_checks.remove(func)  # type: ignore
-        except ValueError:
-            pass
-
-    def application_command_check(self, func: Callable) -> ApplicationCheck:
-        r"""A decorator that adds a global application check to the bot.
-
-        A global check is similar to a :func:`.check` that is applied
-        on a per command basis except it is run before any command checks
-        have been verified and applies to every command the bot has.
-
-        .. note::
-
-            This function can either be a regular function or a coroutine.
-
-        Similar to a command :func:`.check`\, this takes a single parameter
-        of type :class:`.Interaction` and can only raise exceptions inherited from
-        :exc:`.ApplicationError`.
-
-        Example
-        -------
-
-        .. code-block:: python3
-
-            @client.check
-            def check_commands(interaction: Interaction) -> bool:
-                return interaction.application_command.qualified_name in allowed_commands
-
-        """
-        return self.add_application_command_check(func)  # type: ignore
-
-    def application_command_before_invoke(self, coro: ApplicationHook) -> ApplicationHook:
-        """A decorator that registers a coroutine as a pre-invoke hook.
-
-        A pre-invoke hook is called directly before the command is
-        called. This makes it a useful function to set up database
-        connections or any type of set up required.
-
-        This pre-invoke hook takes a sole parameter, a :class:`.Interaction`.
-
-        .. note::
-
-            The :meth:`.application_command_before_invoke` and :meth:`.application_command_after_invoke`
-            hooks are only called if all checks pass without error. If any check fails, then the hooks
-            are not called.
-
-        Parameters
-        ----------
-        coro: :ref:`coroutine <coroutine>`
-            The coroutine to register as the pre-invoke hook.
-
-        Raises
-        ------
-        TypeError
-            The coroutine passed is not actually a coroutine.
-        """
-        if not asyncio.iscoroutinefunction(coro):
-            raise TypeError("The pre-invoke hook must be a coroutine.")
-
-        self._connection._application_command_before_invoke = coro  # type: ignore
-        return coro
-
-    def application_command_after_invoke(self, coro: ApplicationHook) -> ApplicationHook:
-        r"""A decorator that registers a coroutine as a post-invoke hook.
-
-        A post-invoke hook is called directly after the command is
-        called. This makes it a useful function to clean-up database
-        connections or any type of clean up required. There may only be
-        one global post-invoke hook.
-
-        This post-invoke hook takes a sole parameter, a :class:`.Interaction`.
-
-        .. note::
-
-            Similar to :meth:`~.Client.application_command_before_invoke`\, this is not called unless
-            checks succeed. This hook is, however, **always** called regardless of the internal command
-            callback raising an error (i.e. :exc:`.ApplicationInvokeError`\).
-            This makes it ideal for clean-up scenarios.
-
-        Parameters
-        ----------
-        coro: :ref:`coroutine`
-            The coroutine to register as the post-invoke hook.
-
-        Raises
-        ------
-        TypeError
-            The coroutine passed is not actually a coroutine.
-        """
-        if not asyncio.iscoroutinefunction(coro):
-            raise TypeError("The post-invoke hook must be a coroutine.")
-
-        self._connection._application_command_after_invoke = coro  # type: ignore
-        return coro
-
 
 class Bot(BotBase, nextcord.Client):
     """Represents a discord bot.
@@ -1630,7 +1446,7 @@ class Bot(BotBase, nextcord.Client):
                 [Union[Bot, AutoShardedBot], Message],
                 Union[Awaitable[_NonCallablePrefix], _NonCallablePrefix],
             ],
-        ] = tuple(),
+        ] = (),
         help_command: Optional[HelpCommand] = MISSING,
         description: Optional[str] = None,
         *,
@@ -1718,7 +1534,7 @@ class AutoShardedBot(BotBase, nextcord.AutoShardedClient):
                 [Union[Bot, AutoShardedBot], Message],
                 Union[Awaitable[_NonCallablePrefix], _NonCallablePrefix],
             ],
-        ] = tuple(),
+        ] = (),
         help_command: Optional[HelpCommand] = MISSING,
         description: Optional[str] = None,
         *,
