@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
 import datetime
 import functools
 import inspect
@@ -73,15 +74,11 @@ T = TypeVar("T")
 CogT = TypeVar("CogT", bound="Cog")
 CommandT = TypeVar("CommandT", bound="Command")
 ContextT = TypeVar("ContextT", bound="Context")
-# CHT = TypeVar('CHT', bound='Check')
 GroupT = TypeVar("GroupT", bound="Group")
 HookT = TypeVar("HookT", bound="Hook")
 ErrorT = TypeVar("ErrorT", bound="Error")
 
-if TYPE_CHECKING:
-    P = ParamSpec("P")
-else:
-    P = TypeVar("P")
+P = ParamSpec("P") if TYPE_CHECKING else TypeVar("P")
 
 
 def unwrap_function(function: Callable[..., Any]) -> Callable[..., Any]:
@@ -128,7 +125,7 @@ def wrap_callback(coro):
         except CommandError:
             raise
         except asyncio.CancelledError:
-            return
+            return None
         except Exception as exc:
             raise CommandInvokeError(exc) from exc
         return ret
@@ -146,7 +143,7 @@ def hooked_wrapped_callback(command, ctx, coro):
             raise
         except asyncio.CancelledError:
             ctx.command_failed = True
-            return
+            return None
         except Exception as exc:
             ctx.command_failed = True
             raise CommandInvokeError(exc) from exc
@@ -164,7 +161,7 @@ class _CaseInsensitiveDict(dict):
     def __contains__(self, k) -> bool:
         return super().__contains__(k.casefold())
 
-    def __delitem__(self, k):
+    def __delitem__(self, k) -> None:
         return super().__delitem__(k.casefold())
 
     def __getitem__(self, k):
@@ -264,9 +261,10 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
 
         .. versionadded:: 2.0.0
     """
+
     __original_kwargs__: Dict[str, Any]
 
-    def __new__(cls, *args: Any, **kwargs: Any) -> Self:
+    def __new__(cls, *_args: Any, **kwargs: Any) -> Self:
         # if you're wondering why this is done, it's because we need to ensure
         # we have a complete original copy of **kwargs even for classes that
         # mess with it by popping before delegating to the subclass __init__.
@@ -405,6 +403,74 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
 
         self.checks.extend(self.parent.checks)  # type: ignore
 
+    @property
+    def required_permissions(self) -> Dict[str, bool]:
+        """Returns the permissions required to run this command.
+
+        .. note::
+
+            This returns the permissions set with :func:`.has_permissions`.
+
+        .. versionadded:: 2.6
+
+        Returns
+        -------
+        Dict[:class:`str`, :class:`bool`]
+            A dictionary of the required permissions for this command.
+        """
+        return getattr(self.callback, "__required_permissions", {})
+
+    @property
+    def required_bot_permissions(self) -> Dict[str, bool]:
+        """Returns the permissions the bot needs to run this command.
+
+        .. note::
+
+            This returns the permissions set with :func:`.bot_has_permissions`.
+
+        .. versionadded:: 2.6
+
+        Returns
+        -------
+        Dict[:class:`str`, :class:`bool`]
+            A dictionary of the required permissions for this command.
+        """
+        return getattr(self.callback, "__required_bot_permissions", {})
+
+    @property
+    def required_guild_permissions(self) -> Dict[str, bool]:
+        """Returns the guild permissions needed to run this command.
+
+        .. note::
+
+            This returns the permissions set with :func:`.has_guild_permissions`.
+
+        .. versionadded:: 2.6
+
+        Returns
+        -------
+        Dict[:class:`str`, :class:`bool`]
+            A dictionary of the required permissions for this command.
+        """
+        return getattr(self.callback, "__required_guild_permissions", {})
+
+    @property
+    def required_bot_guild_permissions(self) -> Dict[str, bool]:
+        """Returns the permissions the bot needs to have in this guild in order to run this command.
+
+        .. note::
+
+            This returns the permissions set with :func:`.bot_has_guild_permissions`.
+
+        .. versionadded:: 2.6
+
+        Returns
+        -------
+        Dict[:class:`str`, :class:`bool`]
+            A dictionary of the required permissions for this command.
+        """
+        return getattr(self.callback, "__required_bot_guild_permissions", {})
+
     @property
     def callback(
         self,
@@ -462,10 +528,8 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             The function to remove from the checks.
         """
 
-        try:
+        with contextlib.suppress(ValueError):
             self.checks.remove(func)
-        except ValueError:
-            pass
 
     def update(self, **kwargs: Any) -> None:
         """Updates :class:`Command` instance with updated attribute.
@@ -491,8 +555,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         """
         if self.cog is not None:
             return await self.callback(self.cog, context, *args, **kwargs)  # type: ignore
-        else:
-            return await self.callback(context, *args, **kwargs)  # type: ignore
+        return await self.callback(context, *args, **kwargs)  # type: ignore
 
     def _ensure_assignment_on_copy(self, other: CommandT) -> CommandT:
         other._before_invoke = self._before_invoke
@@ -505,10 +568,8 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             # _max_concurrency won't be None at this point
             other._max_concurrency = self._max_concurrency.copy()  # type: ignore
 
-        try:
+        with contextlib.suppress(AttributeError):
             other.on_error = self.on_error
-        except AttributeError:
-            pass
         return other
 
     def copy(self) -> Self:
@@ -528,8 +589,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             kw.update(self.__original_kwargs__)
             copy = self.__class__(self.callback, **kw)
             return self._ensure_assignment_on_copy(copy)
-        else:
-            return self.copy()
+        return self.copy()
 
     async def dispatch_error(self, ctx: Context, error: Exception) -> None:
         ctx.command_failed = True
@@ -566,17 +626,17 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         if isinstance(converter, Greedy):
             if param.kind in (param.POSITIONAL_OR_KEYWORD, param.POSITIONAL_ONLY):
                 return await self._transform_greedy_pos(ctx, param, required, converter.converter)
-            elif param.kind == param.VAR_POSITIONAL:
+            if param.kind == param.VAR_POSITIONAL:
                 return await self._transform_greedy_var_pos(ctx, param, converter.converter)
-            else:
-                # if we're here, then it's a KEYWORD_ONLY param type
-                # since this is mostly useless, we'll helpfully transform Greedy[X]
-                # into just X and do the parsing that way.
-                converter = converter.converter
+
+            # if we're here, then it's a KEYWORD_ONLY param type
+            # since this is mostly useless, we'll helpfully transform Greedy[X]
+            # into just X and do the parsing that way.
+            converter = converter.converter
 
         if view.eof:
             if param.kind == param.VAR_POSITIONAL:
-                raise RuntimeError()  # break the loop
+                raise RuntimeError  # break the loop
             if required:
                 if self._is_typing_optional(param.annotation):
                     return None
@@ -591,17 +651,16 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         else:
             try:
                 argument = view.get_quoted_word()
-            except ArgumentParsingError as exc:
+            except ArgumentParsingError:
                 if self._is_typing_optional(param.annotation):
                     view.index = previous
                     return None
-                else:
-                    raise exc
+                raise
         view.previous = previous
 
         if argument is None:
             if param.kind == param.VAR_POSITIONAL:
-                raise RuntimeError()
+                raise RuntimeError
             if required:
                 if self._is_typing_optional(param.annotation):
                     return None
@@ -644,7 +703,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             value = await run_converters(ctx, converter, argument, param)  # type: ignore
         except (CommandError, ArgumentParsingError):
             view.index = previous
-            raise RuntimeError() from None  # break loop
+            raise RuntimeError from None  # break loop
         else:
             return value
 
@@ -729,8 +788,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         parent = self.full_parent_name
         if parent:
             return parent + " " + self.name
-        else:
-            return self.name
+        return self.name
 
     def __str__(self) -> str:
         return self.qualified_name
@@ -752,7 +810,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             except StopIteration:
                 raise nextcord.ClientException(
                     f'Callback for {self.name} command is missing "self" parameter.'
-                )
+                ) from None
 
         # next we have the 'ctx' as the next parameter
         try:
@@ -760,7 +818,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         except StopIteration:
             raise nextcord.ClientException(
                 f'Callback for {self.name} command is missing "ctx" parameter.'
-            )
+            ) from None
 
         for name, param in iterator:
             ctx.current_parameter = param
@@ -838,10 +896,9 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             dt = ctx.message.edited_at or ctx.message.created_at
             current = dt.replace(tzinfo=datetime.timezone.utc).timestamp()
             bucket = self._buckets.get_bucket(ctx.message, current)
-            if bucket is not None:
-                retry_after = bucket.update_rate_limit(current)
-                if retry_after:
-                    raise CommandOnCooldown(bucket, retry_after, self._buckets.type)  # type: ignore
+            retry_after = bucket.update_rate_limit(current)
+            if retry_after:
+                raise CommandOnCooldown(bucket, retry_after, self._buckets.type)  # type: ignore
 
     async def prepare(self, ctx: Context) -> None:
         ctx.command = self
@@ -1103,8 +1160,8 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
                         else f"[{name}={param.default}]..."
                     )
                     continue
-                else:
-                    result.append(f"[{name}]")
+
+                result.append(f"[{name}]")
 
             elif param.kind == param.VAR_POSITIONAL:
                 if self.require_var_positional:
@@ -1330,9 +1387,9 @@ class GroupMixin(Generic[CogT]):
         if not isinstance(obj, GroupMixin):
             return obj
 
-        for name in names[1:]:
+        for cmd_name in names[1:]:
             try:
-                obj = obj.all_commands[name]  # type: ignore
+                obj = obj.all_commands[cmd_name]  # type: ignore
             except (AttributeError, KeyError):
                 return None
 
@@ -1342,7 +1399,7 @@ class GroupMixin(Generic[CogT]):
     def command(
         self,
         name: str = ...,
-        cls: Type[Command[CogT, P, T]] = Command[CogT, P, T],
+        cls: Type[Command[CogT, P, T]] = Command,
         *args: Any,
         **kwargs: Any,
     ) -> Callable[
@@ -1353,8 +1410,7 @@ class GroupMixin(Generic[CogT]):
             ]
         ],
         Command[CogT, P, T],
-    ]:
-        ...
+    ]: ...
 
     @overload
     def command(
@@ -1363,8 +1419,7 @@ class GroupMixin(Generic[CogT]):
         cls: Type[CommandT] = Command,
         *args: Any,
         **kwargs: Any,
-    ) -> Callable[[Callable[Concatenate[Context, P], Coro[Any]]], CommandT]:
-        ...
+    ) -> Callable[[Callable[Concatenate[Context, P], Coro[Any]]], CommandT]: ...
 
     def command(
         self,
@@ -1384,7 +1439,7 @@ class GroupMixin(Generic[CogT]):
 
         def decorator(func: Callable[Concatenate[ContextT, P], Coro[Any]]) -> CommandT:
             kwargs.setdefault("parent", self)
-            result = command(name=name, cls=cls, *args, **kwargs)(func)
+            result = command(name, cls, *args, **kwargs)(func)
             self.add_command(result)
             return result  # type: ignore
             # pyright really doesnt know what typevars are
@@ -1406,8 +1461,7 @@ class GroupMixin(Generic[CogT]):
             ]
         ],
         Group[CogT, P, T],
-    ]:
-        ...
+    ]: ...
 
     @overload
     def group(
@@ -1416,8 +1470,7 @@ class GroupMixin(Generic[CogT]):
         cls: Type[GroupT] = MISSING,
         *args: Any,
         **kwargs: Any,
-    ) -> Callable[[Callable[Concatenate[Context, P], Coro[Any]]], GroupT]:
-        ...
+    ) -> Callable[[Callable[Concatenate[Context, P], Coro[Any]]], GroupT]: ...
 
     def group(
         self,
@@ -1437,7 +1490,7 @@ class GroupMixin(Generic[CogT]):
 
         def decorator(func: Callable[Concatenate[ContextT, P], Coro[Any]]) -> GroupT:
             kwargs.setdefault("parent", self)
-            result = group(name=name, cls=cls, *args, **kwargs)(func)
+            result = group(name, *args, cls=cls, **kwargs)(func)
             self.add_command(result)  # type: ignore
             return result  # type: ignore
 
@@ -1470,7 +1523,7 @@ class Group(GroupMixin[CogT], Command[CogT, P, T]):
     def __init__(self, *args: Any, **attrs: Any) -> None:
         self.invoke_without_command: bool = attrs.pop("invoke_without_command", False)
         GroupMixin.__init__(self, *args, **attrs)
-        Command.__init__(self, *args, **attrs)  # type: ignore
+        Command.__init__(self, *args, **attrs)
 
     def copy(self) -> Self:
         """Creates a copy of this :class:`Group`.
@@ -1563,7 +1616,7 @@ class Group(GroupMixin[CogT], Command[CogT, P, T]):
 @overload
 def command(
     name: str = ...,
-    cls: Type[Command[CogT, P, T]] = Command[CogT, P, T],
+    cls: Type[Command[CogT, P, T]] = Command,
     **attrs: Any,
 ) -> Callable[
     [
@@ -1573,8 +1626,7 @@ def command(
         ]
     ],
     Command[CogT, P, T],
-]:
-    ...
+]: ...
 
 
 @overload
@@ -1590,8 +1642,7 @@ def command(
         ]
     ],
     CommandT,
-]:
-    ...
+]: ...
 
 
 def command(
@@ -1656,13 +1707,12 @@ def group(
 ) -> Callable[
     [
         Union[
-            Callable[Concatenate[Cog, ContextT, P], Coro[T]],
+            Callable[Concatenate[CogT, ContextT, P], Coro[T]],
             Callable[Concatenate[ContextT, P], Coro[T]],
         ]
     ],
-    Group[Cog, P, T],
-]:
-    ...
+    Group[CogT, P, T],
+]: ...
 
 
 @overload
@@ -1678,8 +1728,7 @@ def group(
         ]
     ],
     Group[CogT, P, T],
-]:
-    ...
+]: ...
 
 
 @overload
@@ -1695,8 +1744,7 @@ def group(
         ]
     ],
     GroupT,
-]:
-    ...
+]: ...
 
 
 def group(
@@ -1812,7 +1860,7 @@ def check(predicate: Check) -> Callable[[T], T]:
         decorator.predicate = predicate
     else:
 
-        @functools.wraps(predicate)
+        @functools.wraps(predicate)  # type: ignore
         async def wrapper(ctx):
             return predicate(ctx)  # type: ignore
 
@@ -1919,7 +1967,7 @@ def has_role(item: Union[int, str]) -> Callable[[T], T]:
 
     def predicate(ctx: Context) -> bool:
         if ctx.guild is None:
-            raise NoPrivateMessage()
+            raise NoPrivateMessage
 
         # ctx.guild is None doesn't narrow ctx.author to Member
         if isinstance(item, int):
@@ -1967,7 +2015,7 @@ def has_any_role(*items: Union[int, str]) -> Callable[[T], T]:
 
     def predicate(ctx) -> bool:
         if ctx.guild is None:
-            raise NoPrivateMessage()
+            raise NoPrivateMessage
 
         # ctx.guild is None doesn't narrow ctx.author to Member
         getter = functools.partial(nextcord.utils.get, ctx.author.roles)
@@ -1997,7 +2045,7 @@ def bot_has_role(item: int) -> Callable[[T], T]:
 
     def predicate(ctx) -> bool:
         if ctx.guild is None:
-            raise NoPrivateMessage()
+            raise NoPrivateMessage
 
         me = ctx.me
         if isinstance(item, int):
@@ -2027,7 +2075,7 @@ def bot_has_any_role(*items: int) -> Callable[[T], T]:
 
     def predicate(ctx) -> bool:
         if ctx.guild is None:
-            raise NoPrivateMessage()
+            raise NoPrivateMessage
 
         me = ctx.me
         getter = functools.partial(nextcord.utils.get, me.roles)
@@ -2041,6 +2089,18 @@ def bot_has_any_role(*items: int) -> Callable[[T], T]:
     return check(predicate)
 
 
+def _permission_check_wrapper(
+    predicate: Check, name: str, perms: Dict[str, bool]
+) -> Callable[[T], T]:
+    def wrapper(func: Union[Command, CoroFunc]) -> Union[Command, CoroFunc]:
+        callback = func.callback if isinstance(func, Command) else func
+
+        setattr(callback, name, perms)
+        return check(predicate)(func)
+
+    return wrapper  # type: ignore
+
+
 def has_permissions(**perms: bool) -> Callable[[T], T]:
     """A :func:`.check` that is added that checks if the member has all of
     the permissions necessary.
@@ -2086,7 +2146,7 @@ def has_permissions(**perms: bool) -> Callable[[T], T]:
 
         raise MissingPermissions(missing)
 
-    return check(predicate)
+    return _permission_check_wrapper(predicate, "__required_permissions", perms)
 
 
 def bot_has_permissions(**perms: bool) -> Callable[[T], T]:
@@ -2113,7 +2173,7 @@ def bot_has_permissions(**perms: bool) -> Callable[[T], T]:
 
         raise BotMissingPermissions(missing)
 
-    return check(predicate)
+    return _permission_check_wrapper(predicate, "__required_bot_permissions", perms)
 
 
 def has_guild_permissions(**perms: bool) -> Callable[[T], T]:
@@ -2142,7 +2202,7 @@ def has_guild_permissions(**perms: bool) -> Callable[[T], T]:
 
         raise MissingPermissions(missing)
 
-    return check(predicate)
+    return _permission_check_wrapper(predicate, "__required_guild_permissions", perms)
 
 
 def bot_has_guild_permissions(**perms: bool) -> Callable[[T], T]:
@@ -2168,7 +2228,7 @@ def bot_has_guild_permissions(**perms: bool) -> Callable[[T], T]:
 
         raise BotMissingPermissions(missing)
 
-    return check(predicate)
+    return _permission_check_wrapper(predicate, "__required_bot_guild_permissions", perms)
 
 
 def dm_only() -> Callable[[T], T]:
@@ -2184,7 +2244,7 @@ def dm_only() -> Callable[[T], T]:
 
     def predicate(ctx: Context) -> bool:
         if ctx.guild is not None:
-            raise PrivateMessageOnly()
+            raise PrivateMessageOnly
         return True
 
     return check(predicate)
@@ -2201,7 +2261,7 @@ def guild_only() -> Callable[[T], T]:
 
     def predicate(ctx: Context) -> bool:
         if ctx.guild is None:
-            raise NoPrivateMessage()
+            raise NoPrivateMessage
         return True
 
     return check(predicate)
