@@ -210,6 +210,7 @@ class Loop(Generic[LF]):
         """
         if self._seconds is not MISSING:
             return self._seconds
+        return None
 
     @property
     def minutes(self) -> Optional[float]:
@@ -220,6 +221,7 @@ class Loop(Generic[LF]):
         """
         if self._minutes is not MISSING:
             return self._minutes
+        return None
 
     @property
     def hours(self) -> Optional[float]:
@@ -230,6 +232,7 @@ class Loop(Generic[LF]):
         """
         if self._hours is not MISSING:
             return self._hours
+        return None
 
     @property
     def time(self) -> Optional[List[datetime.time]]:
@@ -240,6 +243,7 @@ class Loop(Generic[LF]):
         """
         if self._time is not MISSING:
             return self._time.copy()
+        return None
 
     @property
     def current_loop(self) -> int:
@@ -254,7 +258,7 @@ class Loop(Generic[LF]):
         """
         if self._task is MISSING:
             return None
-        elif self._task and self._task.done() or self._stop_next_iteration:
+        if self._task and self._task.done() or self._stop_next_iteration:
             return None
         return self._next_iteration
 
@@ -356,7 +360,7 @@ class Loop(Generic[LF]):
             The keyword arguments to use.
         """
 
-        def restart_when_over(fut: Any, *, args: Any = args, kwargs: Any = kwargs) -> None:
+        def restart_when_over(_fut: Any, *, args: Any = args, kwargs: Any = kwargs) -> None:
             self._task.remove_done_callback(restart_when_over)
             self.start(*args, **kwargs)
 
@@ -400,7 +404,7 @@ class Loop(Generic[LF]):
 
             This operation obviously cannot be undone!
         """
-        self._valid_exception = tuple()
+        self._valid_exception = ()
 
     def remove_exception_type(self, *exceptions: Type[BaseException]) -> bool:
         r"""Removes exception types from being handled during the reconnect logic.
@@ -442,7 +446,7 @@ class Loop(Generic[LF]):
         return not bool(self._task.done()) if self._task is not MISSING else False
 
     async def _error(self, exception: BaseException) -> None:
-        print(
+        print(  # noqa: T201
             f"Unhandled exception in internal background task {self.coro.__name__!r}.",
             file=sys.stderr,
         )
@@ -547,8 +551,7 @@ class Loop(Generic[LF]):
             self._time_index += 1
             if next_time > utcnow().timetz():
                 return datetime.datetime.combine(utcnow(), next_time)
-            else:
-                return datetime.datetime.combine(utcnow() + datetime.timedelta(days=1), next_time)
+            return datetime.datetime.combine(utcnow() + datetime.timedelta(days=1), next_time)
 
         next_date = self._last_iteration
         if next_time < next_date.timetz():
@@ -561,7 +564,7 @@ class Loop(Generic[LF]):
         # now kwarg should be a datetime.datetime representing the time "now"
         # to calculate the next time index from
 
-        # pre-condition: self._time is set
+        # pre-condition - self._time is set
         time_now = (now if now is not MISSING else utcnow().replace(microsecond=0)).timetz()
         for idx, time in enumerate(self._time):
             if time >= time_now:
@@ -599,8 +602,7 @@ class Loop(Generic[LF]):
                 )
             ret.append(t if t.tzinfo is not None else t.replace(tzinfo=utc))
 
-        ret = sorted(set(ret))  # de-dupe and sort times
-        return ret
+        return sorted(set(ret))  # de-dupe and sort times
 
     def change_interval(
         self,
