@@ -5,13 +5,31 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
 from datetime import datetime, timedelta
-from typing import TYPE_CHECKING, Any, Dict, Generic, List, Optional, Tuple, TypeVar, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Generic,
+    List,
+    Optional,
+    Set,
+    Tuple,
+    TypeVar,
+    Union,
+)
 
 from . import utils
 from .channel import ChannelType, PartialMessageable
 from .embeds import Embed
-from .enums import InteractionResponseType, InteractionType, try_enum
+from .enums import (
+    IntegrationType,
+    InteractionContextType,
+    InteractionResponseType,
+    InteractionType,
+    try_enum,
+)
 from .errors import ClientException, HTTPException, InteractionResponded, InvalidArgument
 from .file import File
 from .flags import MessageFlags
@@ -34,6 +52,7 @@ __all__ = (
 if TYPE_CHECKING:
     from aiohttp import ClientSession
 
+    from .abc import MessageableChannel
     from .application_command import BaseApplicationCommand, SlashApplicationSubcommand
     from .channel import CategoryChannel, ForumChannel, StageChannel, TextChannel, VoiceChannel
     from .client import Client
@@ -42,6 +61,7 @@ if TYPE_CHECKING:
     from .state import ConnectionState
     from .threads import Thread
     from .types.interactions import Interaction as InteractionPayload, InteractionData
+    from .types.message import Message as MessagePayload
     from .ui.modal import Modal
     from .ui.view import View
 
@@ -146,6 +166,19 @@ class Interaction(Hashable, Generic[ClientT]):
         The attached data of the interaction. This is used to store any data you may need inside the interaction for convenience. This data will stay on the interaction, even after a :meth:`Interaction.application_command_before_invoke`.
     application_command: Optional[:class:`ApplicationCommand`]
         The application command that handled the interaction.
+    authorizing_integration_owners: Optional[Dict[:class:`IntegrationType`, :class:`int`]]
+        Mapping of installation contexts that the interaction was authorized for to related user or guild IDs.
+        You can find out about this field in the `official Discord documentation`__.
+
+        .. _integration_docs: https://discord.com/developers/docs/interactions/receiving-and-responding#interaction-object-authorizing-integration-owners-object
+
+        __ integration_docs_
+
+        .. versionadded:: 3.0
+    context: Optional[:class:`InteractionContextType`]
+        Context where the interaction was triggered from.
+
+        .. versionadded:: 3.0
     """
 
     __slots__: Tuple[str, ...] = (
@@ -161,8 +194,11 @@ class Interaction(Hashable, Generic[ClientT]):
         "guild_locale",
         "token",
         "version",
+        "authorizing_integration_owners",
+        "context",
         "application_command",
         "attached",
+        "_background_tasks",
         "_permissions",
         "_app_permissions",
         "_state",
@@ -182,6 +218,7 @@ class Interaction(Hashable, Generic[ClientT]):
         self.application_command: Optional[
             Union[SlashApplicationSubcommand, BaseApplicationCommand]
         ] = None
+        self._background_tasks: Set[asyncio.Task] = set()
         self._from_data(data)
 
     def _from_data(self, data: InteractionPayload) -> None:
@@ -229,6 +266,20 @@ class Interaction(Hashable, Generic[ClientT]):
             except KeyError:
                 pass
 
+        authorizing_integration_owners = data.get("authorizing_integration_owners")
+        self.authorizing_integration_owners: Optional[Dict[IntegrationType, int]]
+        if authorizing_integration_owners is None:
+            self.authorizing_integration_owners = None
+        else:
+            self.authorizing_integration_owners = {
+                try_enum(IntegrationType, int(integration_type)): int(details)
+                for integration_type, details in authorizing_integration_owners.items()
+            }
+
+        self.context: Optional[InteractionContextType] = (
+            try_enum(InteractionContextType, data["context"]) if "context" in data else None
+        )
+
     @property
     def client(self) -> ClientT:
         """:class:`Client`: The client that handled the interaction."""
@@ -249,8 +300,7 @@ class Interaction(Hashable, Generic[ClientT]):
         """:class:`datetime.datetime`: An aware datetime in UTC representing the time when the interaction will expire."""
         if self.response.is_done():
             return self.created_at + timedelta(minutes=15)
-        else:
-            return self.created_at + timedelta(seconds=3)
+        return self.created_at + timedelta(seconds=3)
 
     def is_expired(self) -> bool:
         """:class:`bool` A boolean whether the interaction token is invalid or not."""
@@ -350,8 +400,12 @@ class Interaction(Hashable, Generic[ClientT]):
             token=self.token,
             session=self._session,
         )
-        state = _InteractionMessageState(self, self._state)
-        message = InteractionMessage(state=state, channel=channel, data=data)  # type: ignore
+        message = InteractionMessage(
+            interaction=self,
+            state=self._state,
+            channel=channel,  # type: ignore
+            data=data,
+        )
         self._original_message = message
         return message
 
@@ -442,8 +496,13 @@ class Interaction(Hashable, Generic[ClientT]):
         )
 
         # The message channel types should always match
-        message = InteractionMessage(state=self._state, channel=self.channel, data=data)  # type: ignore
-        if view and not view.is_finished():
+        message = InteractionMessage(
+            interaction=self,
+            state=self._state,
+            channel=self.channel,  # type: ignore
+            data=data,
+        )
+        if view and not view.is_finished() and view.prevent_update:
             self._state.store_view(view, message.id)
         return message
 
@@ -479,12 +538,12 @@ class Interaction(Hashable, Generic[ClientT]):
 
             async def inner_call(delay: float = delay) -> None:
                 await asyncio.sleep(delay)
-                try:
+                with contextlib.suppress(HTTPException):
                     await delete_func
-                except HTTPException:
-                    pass
 
-            asyncio.create_task(inner_call())
+            task = asyncio.create_task(inner_call())
+            self._background_tasks.add(task)
+            task.add_done_callback(self._background_tasks.discard)
         else:
             await delete_func
 
@@ -882,13 +941,12 @@ class InteractionResponse:
         if allowed_mentions is MISSING or allowed_mentions is None:
             if self._parent._state.allowed_mentions is not None:
                 payload["allowed_mentions"] = self._parent._state.allowed_mentions.to_dict()
+        elif self._parent._state.allowed_mentions is not None:
+            payload["allowed_mentions"] = self._parent._state.allowed_mentions.merge(
+                allowed_mentions
+            ).to_dict()
         else:
-            if self._parent._state.allowed_mentions is not None:
-                payload["allowed_mentions"] = self._parent._state.allowed_mentions.merge(
-                    allowed_mentions
-                ).to_dict()
-            else:
-                payload["allowed_mentions"] = allowed_mentions.to_dict()
+            payload["allowed_mentions"] = allowed_mentions.to_dict()
 
         parent = self._parent
         adapter = async_context.get()
@@ -903,10 +961,10 @@ class InteractionResponse:
             )
         finally:
             if files:
-                for file in files:
-                    file.close()
+                for f in files:
+                    f.close()
 
-        if view is not MISSING:
+        if view is not MISSING and view.prevent_update:
             if ephemeral and view.timeout is None:
                 view.timeout = 15 * 60.0
 
@@ -917,8 +975,7 @@ class InteractionResponse:
         if delete_after is not None:
             await self._parent.delete_original_message(delay=delete_after)
 
-        state = _InteractionMessageState(self._parent, self._parent._state)
-        return PartialInteractionMessage(state)
+        return PartialInteractionMessage(self._parent)
 
     async def send_modal(self, modal: Modal) -> None:
         """|coro|
@@ -1034,10 +1091,7 @@ class InteractionResponse:
             raise InvalidArgument("Cannot mix both embed and embeds keyword arguments")
 
         if embed is not MISSING:
-            if embed is None:
-                embeds = []
-            else:
-                embeds = [embed]
+            embeds = [] if embed is None else [embed]
 
         if embeds is not MISSING:
             payload["embeds"] = [e.to_dict() for e in embeds]
@@ -1074,10 +1128,10 @@ class InteractionResponse:
             )
         finally:
             if files:
-                for file in files:
-                    file.close()
+                for f in files:
+                    f.close()
 
-        if view and not view.is_finished() and message_id is not None:
+        if view and not view.is_finished() and message_id is not None and view.prevent_update:
             state.store_view(view, message_id)
 
         self._responded = True
@@ -1088,33 +1142,9 @@ class InteractionResponse:
         return state._get_message(message_id)
 
 
-class _InteractionMessageState:
-    __slots__ = ("_parent", "_interaction")
-
-    def __init__(self, interaction: Interaction, parent: ConnectionState) -> None:
-        self._interaction: Interaction = interaction
-        self._parent: ConnectionState = parent
-
-    def _get_guild(self, guild_id):
-        return self._parent._get_guild(guild_id)
-
-    def store_user(self, data):
-        return self._parent.store_user(data)
-
-    def create_user(self, data):
-        return self._parent.create_user(data)
-
-    @property
-    def http(self):
-        return self._parent.http
-
-    def __getattr__(self, attr):
-        return getattr(self._parent, attr)
-
-
 class _InteractionMessageMixin:
     __slots__ = ()
-    _state: _InteractionMessageState
+    _interaction: Interaction
 
     async def edit(
         self,
@@ -1177,7 +1207,7 @@ class _InteractionMessageMixin:
         :class:`InteractionMessage`
             The newly edited message.
         """
-        message = await self._state._interaction.edit_original_message(
+        message = await self._interaction.edit_original_message(
             content=content,
             embeds=embeds,
             embed=embed,
@@ -1214,7 +1244,7 @@ class _InteractionMessageMixin:
             Deleting the message failed.
         """
 
-        await self._state._interaction.delete_original_message(delay=delay)
+        await self._interaction.delete_original_message(delay=delay)
 
 
 class PartialInteractionMessage(_InteractionMessageMixin):
@@ -1253,8 +1283,8 @@ class PartialInteractionMessage(_InteractionMessageMixin):
         :class:`Interaction` that it is associated with but not that of the full :class:`InteractionMessage`.
     """
 
-    def __init__(self, state: _InteractionMessageState) -> None:
-        self._state = state
+    def __init__(self, interaction: Interaction) -> None:
+        self._interaction: Interaction = interaction
 
     async def fetch(self) -> InteractionMessage:
         """|coro|
@@ -1275,7 +1305,7 @@ class PartialInteractionMessage(_InteractionMessageMixin):
         InteractionMessage
             The original interaction response message.
         """
-        return await self._state._interaction.original_message()
+        return await self._interaction.original_message()
 
     @property
     def author(self) -> Optional[Union[Member, ClientUser]]:
@@ -1284,7 +1314,7 @@ class PartialInteractionMessage(_InteractionMessageMixin):
         If the interaction was in a guild, this is a :class:`Member` representing the client.
         Otherwise, this is a :class:`ClientUser`.
         """
-        return self.guild.me if self.guild else self._state._interaction.client.user
+        return self.guild.me if self.guild else self._interaction.client.user
 
     @property
     def channel(self) -> Optional[InteractionChannel]:
@@ -1293,29 +1323,28 @@ class PartialInteractionMessage(_InteractionMessageMixin):
         Note that due to a Discord limitation, DM channels are not resolved since there is
         no data to complete them. These are :class:`PartialMessageable` instead.
         """
-        return self._state._interaction.channel
+        return self._interaction.channel
 
     @property
     def guild(self) -> Optional[Guild]:
         """Optional[:class:`Guild`]: The guild the interaction was sent from."""
-        return self._state._interaction.guild
+        return self._interaction.guild
 
     def __repr__(self) -> str:
         return f"<{self.__class__.__name__} author={self.author!r} channel={self.channel!r} guild={self.guild!r}>"
 
     def __eq__(self, other: object) -> bool:
         return (
-            isinstance(other, PartialInteractionMessage)
-            and self._state._interaction == other._state._interaction
+            isinstance(other, PartialInteractionMessage) and self._interaction == other._interaction
         )
 
     def __ne__(self, other: object) -> bool:
         if isinstance(other, PartialInteractionMessage):
-            return self._state._interaction != other._state._interaction
+            return self._interaction != other._interaction
         return True
 
     def __hash__(self) -> int:
-        return hash(self._state._interaction)
+        return hash(self._interaction)
 
 
 class InteractionMessage(_InteractionMessageMixin, Message):
@@ -1330,4 +1359,13 @@ class InteractionMessage(_InteractionMessageMixin, Message):
     .. versionadded:: 2.0
     """
 
-    pass
+    def __init__(
+        self,
+        *,
+        interaction: Interaction,
+        state: ConnectionState,
+        channel: MessageableChannel,
+        data: MessagePayload,
+    ) -> None:
+        super().__init__(state=state, channel=channel, data=data)
+        self._interaction: Interaction = interaction
