@@ -4,9 +4,11 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, List, Optional, Union
 
+from nextcord.types.guild import GuildFeature
+
 from .appinfo import PartialAppInfo
 from .asset import Asset
-from .enums import ChannelType, InviteTarget, VerificationLevel, try_enum
+from .enums import ChannelType, InviteTarget, InviteType, VerificationLevel, try_enum
 from .mixins import Hashable
 from .object import Object
 from .utils import get_as_snowflake, parse_time, snowflake_time
@@ -150,7 +152,7 @@ class PartialInviteGuild:
         self._state: ConnectionState = state
         self.id: int = id
         self.name: str = data["name"]
-        self.features: List[str] = data.get("features", [])
+        self.features: List[GuildFeature] = data.get("features", [])
         self._icon: Optional[str] = data.get("icon")
         self._banner: Optional[str] = data.get("banner")
         self._splash: Optional[str] = data.get("splash")
@@ -293,6 +295,10 @@ class Invite(Hashable):
         The embedded application the invite targets, if any.
 
         .. versionadded:: 2.0
+    type: :class:`InviteType`
+        The type of invite.
+
+        .. versionadded:: 3.0
     """
 
     __slots__ = (
@@ -313,6 +319,7 @@ class Invite(Hashable):
         "approximate_presence_count",
         "target_application",
         "expires_at",
+        "type",
     )
 
     BASE = "https://discord.gg"
@@ -326,6 +333,7 @@ class Invite(Hashable):
         channel: Optional[Union[PartialInviteChannel, GuildChannel]] = None,
     ) -> None:
         self._state: ConnectionState = state
+        self.type: InviteType = try_enum(InviteType, data.get("type"))
         self.max_age: Optional[int] = data.get("max_age")
         self.code: Optional[str] = data.get("code")
         self.guild: Optional[InviteGuildType] = self._resolve_guild(data.get("guild"), guild)
@@ -432,7 +440,7 @@ class Invite(Hashable):
 
     def __repr__(self) -> str:
         return (
-            f"<Invite code={self.code!r} guild={self.guild!r} "
+            f"<Invite type={self.type!r} code={self.code!r} guild={self.guild!r} "
             f"online={self.approximate_presence_count} "
             f"members={self.approximate_member_count}>"
         )
