@@ -3,9 +3,12 @@
 from __future__ import annotations
 
 import asyncio
+import base64
+import contextlib
 import datetime
 import io
 import re
+from array import array
 from os import PathLike
 from typing import (
     TYPE_CHECKING,
@@ -15,6 +18,7 @@ from typing import (
     Dict,
     List,
     Optional,
+    Set,
     Tuple,
     Union,
     overload,
@@ -24,23 +28,31 @@ from . import utils
 from .components import _component_factory
 from .embeds import Embed
 from .emoji import Emoji
-from .enums import ChannelType, MessageType, try_enum
+from .enums import ChannelType, IntegrationType, MessageReferenceType, MessageType, try_enum
 from .errors import HTTPException, InvalidArgument
 from .file import File
-from .flags import MessageFlags
+from .flags import AttachmentFlags, MessageFlags
 from .guild import Guild
 from .member import Member
 from .mixins import Hashable
+from .object import Object
 from .partial_emoji import PartialEmoji
 from .reaction import Reaction
 from .sticker import StickerItem
 from .threads import Thread
+from .user import User
 from .utils import MISSING, escape_mentions
 
 if TYPE_CHECKING:
     from typing_extensions import Self
 
-    from .abc import GuildChannel, MessageableChannel, PartialMessageableChannel, Snowflake
+    from .abc import (
+        GuildChannel,
+        Messageable,
+        MessageableChannel,
+        PartialMessageableChannel,
+        Snowflake,
+    )
     from .channel import TextChannel
     from .components import Component
     from .mentions import AllowedMentions
@@ -48,7 +60,10 @@ if TYPE_CHECKING:
     from .state import ConnectionState
     from .types.components import Component as ComponentPayload
     from .types.embed import Embed as EmbedPayload
-    from .types.interactions import MessageInteraction as MessageInteractionPayload
+    from .types.interactions import (
+        MessageInteraction as MessageInteractionPayload,
+        MessageInteractionMetadata as MessageInteractionMetadataPayload,
+    )
     from .types.member import Member as MemberPayload, UserWithMember as UserWithMemberPayload
     from .types.message import (
         Attachment as AttachmentPayload,
@@ -56,6 +71,7 @@ if TYPE_CHECKING:
         MessageActivity as MessageActivityPayload,
         MessageApplication as MessageApplicationPayload,
         MessageReference as MessageReferencePayload,
+        MessageSnapshot as MessageSnapshotPayload,
         Reaction as ReactionPayload,
     )
     from .types.threads import Thread as ThreadPayload, ThreadArchiveDuration
@@ -72,6 +88,8 @@ __all__ = (
     "MessageReference",
     "DeletedReferencedMessage",
     "MessageInteraction",
+    "MessageInteractionMetadata",
+    "MessageSnapshot",
 )
 
 
@@ -144,6 +162,10 @@ class Attachment(Hashable):
         The attachment's description. This is used for alternative text in the Discord client.
 
         .. versionadded:: 2.0
+    duration_secs: Optional[:class:`float`]
+        The duration of the audio file (currently for voice messages).
+
+        .. versionadded:: 3.0
     """
 
     __slots__ = (
@@ -157,6 +179,10 @@ class Attachment(Hashable):
         "_http",
         "content_type",
         "description",
+        "duration_secs",
+        "_waveform",
+        "_cs_waveform",
+        "_flags",
     )
 
     def __init__(self, *, data: AttachmentPayload, state: ConnectionState) -> None:
@@ -170,6 +196,9 @@ class Attachment(Hashable):
         self._http = state.http
         self.content_type: Optional[str] = data.get("content_type")
         self.description: Optional[str] = data.get("description")
+        self.duration_secs: Optional[float] = data.get("duration_secs")
+        self._waveform: Optional[str] = data.get("waveform")
+        self._flags: int = data.get("flags", 0)
 
     def is_spoiler(self) -> bool:
         """:class:`bool`: Whether this attachment contains a spoiler."""
@@ -227,9 +256,9 @@ class Attachment(Hashable):
             if seek_begin:
                 fp.seek(0)
             return written
-        else:
-            with open(fp, "wb") as f:
-                return f.write(data)
+
+        with open(fp, "wb") as f:  # noqa: ASYNC230
+            return f.write(data)
 
     async def read(self, *, use_cached: bool = False) -> bytes:
         """|coro|
@@ -263,8 +292,7 @@ class Attachment(Hashable):
             The contents of the attachment.
         """
         url = self.proxy_url if use_cached else self.url
-        data = await self._http.get_from_cdn(url)
-        return data
+        return await self._http.get_from_cdn(url)
 
     async def to_file(
         self,
@@ -359,8 +387,34 @@ class Attachment(Hashable):
             result["content_type"] = self.content_type
         if self.description:
             result["description"] = self.description
+        if self.duration_secs:
+            result["duration_secs"] = self.duration_secs
+        if self._waveform:
+            result["waveform"] = self._waveform
         return result
 
+    @utils.cached_slot_property("_cs_waveform")
+    def waveform(self) -> Optional[array[int]]:
+        """Optional[array[:class:`int`]]: The base64 decoded data representing a sampled waveform
+        (currently for voice messages).
+
+        .. versionadded:: 3.0
+        """
+        if self._waveform is not None:
+            return array("B", base64.b64decode(self._waveform))
+        return None
+
+    def flags(self) -> AttachmentFlags:
+        """Optional[:class:`AttachmentFlags`]: The avaliable flags that the attachment has.
+
+        .. versionadded:: 2.6
+        """
+        return AttachmentFlags._from_value(self._flags)
+
+    def is_remix(self) -> bool:
+        """:class:`bool`: Whether the attachment is remixed."""
+        return self.flags.is_remix
+
 
 class DeletedReferencedMessage:
     """A special sentinel type that denotes whether the
@@ -429,19 +483,33 @@ class MessageReference:
         Currently, this is mainly the replied to message when a user replies to a message.
 
         .. versionadded:: 1.6
+    type: :class:`~nextcord.MessageReferenceType`
+        The type of reference that the message is. Defaults to a reply.
+
+        .. versionadded:: 3.0
     """
 
-    __slots__ = ("message_id", "channel_id", "guild_id", "fail_if_not_exists", "resolved", "_state")
+    __slots__ = (
+        "message_id",
+        "channel_id",
+        "guild_id",
+        "fail_if_not_exists",
+        "resolved",
+        "_state",
+        "type",
+    )
 
     def __init__(
         self,
         *,
         message_id: int,
         channel_id: int,
+        type: MessageReferenceType = MessageReferenceType.default,
         guild_id: Optional[int] = None,
         fail_if_not_exists: bool = True,
     ) -> None:
         self._state: Optional[ConnectionState] = None
+        self.type: MessageReferenceType = type
         self.resolved: Optional[Union[Message, DeletedReferencedMessage]] = None
         self.message_id: Optional[int] = message_id
         self.channel_id: int = channel_id
@@ -451,6 +519,7 @@ class MessageReference:
     @classmethod
     def with_state(cls, state: ConnectionState, data: MessageReferencePayload) -> Self:
         self = cls.__new__(cls)
+        self.type = MessageReferenceType(data.get("type", 0))
         self.message_id = utils.get_as_snowflake(data, "message_id")
         self.channel_id = int(data.pop("channel_id"))
         self.guild_id = utils.get_as_snowflake(data, "guild_id")
@@ -460,7 +529,13 @@ class MessageReference:
         return self
 
     @classmethod
-    def from_message(cls, message: Message, *, fail_if_not_exists: bool = True) -> Self:
+    def from_message(
+        cls,
+        message: Message,
+        *,
+        type: MessageReferenceType = MessageReferenceType.default,
+        fail_if_not_exists: bool = True,
+    ) -> Self:
         """Creates a :class:`MessageReference` from an existing :class:`~nextcord.Message`.
 
         .. versionadded:: 1.6
@@ -469,6 +544,10 @@ class MessageReference:
         ----------
         message: :class:`~nextcord.Message`
             The message to be converted into a reference.
+        type: :class:`~nextcord.MessageReferenceType`
+            The type of reference that the message is. Defaults to the ``reply`` type  if not provided.
+
+            .. versionadded:: 3.0
         fail_if_not_exists: :class:`bool`
             Whether replying to the referenced message should raise :class:`HTTPException`
             if the message no longer exists or Discord could not fetch the message.
@@ -481,6 +560,7 @@ class MessageReference:
             A reference to the message.
         """
         self = cls(
+            type=type,
             message_id=message.id,
             channel_id=message.channel.id,
             guild_id=getattr(message.guild, "id", None),
@@ -510,11 +590,11 @@ class MessageReference:
         result: MessageReferencePayload = (
             {"message_id": self.message_id} if self.message_id is not None else {}
         )
+        result["type"] = self.type.value
         result["channel_id"] = self.channel_id
+        result["fail_if_not_exists"] = self.fail_if_not_exists
         if self.guild_id is not None:
             result["guild_id"] = self.guild_id
-        if self.fail_if_not_exists is not None:
-            result["fail_if_not_exists"] = self.fail_if_not_exists
         return result
 
     to_message_reference_dict = to_dict
@@ -535,6 +615,67 @@ def flatten_handlers(cls):
     return cls
 
 
+class MessageSnapshot:
+    """Represents a message reference snapshot.
+
+    .. versionadded:: 3.0
+
+    Attributes
+    ----------
+    type: :class:`MessageType`
+        The type of message.
+    content: :class:`str`
+        The message's content.
+    embeds: List[:class:`Embed`]
+        The embeds the message contains.
+    attachments: List[:class:`Attachment`]
+        The attachments the message contains.
+    timestamp: :class:`datetime.datetime`
+        The timestamp when the message was sent.
+    edited_timestamp: Optional[:class:`datetime.datetime`]
+        The timestamp when the message was last edited.
+        Returns ``None`` if it has not been edited.
+    flags: :class:`MessageFlags`
+        The message's flags.
+    mentions: List[:class:`User`]
+        A list of users that the message has mentioned.
+    mention_roles: List[:class:`Object`]
+        A list of role IDs that the message has mentioned.
+    sticker_items: List[:class:`StickerItem`]
+        A list of stickers packs that the message contains.
+    components: List[:class:`Component`]
+        A list of components that the message contains.
+    """
+
+    def __init__(self, *, data: MessageSnapshotPayload, state: ConnectionState) -> None:
+        self._message = data["message"]
+        self._state = state
+
+        self.type: MessageType = MessageType(self._message["type"])
+        self.content: str = self._message["content"]
+        self.embeds: List[Embed] = [Embed.from_dict(d) for d in self._message.get("embeds", [])]
+        self.attachments: List[Attachment] = [
+            Attachment(data=a, state=self._state) for a in self._message.get("attachments", [])
+        ]
+        self.timestamp: datetime.datetime = utils.parse_time(self._message["timestamp"])
+        self.edited_timestamp: datetime.datetime | None = utils.parse_time(
+            self._message.get("edited_timestamp")
+        )
+        self.flags: MessageFlags = MessageFlags._from_value(self._message.get("flags", 0))
+        self.mentions: List[User] = [
+            User(state=self._state, data=u) for u in self._message.get("mentions", [])
+        ]
+        self.mention_roles: List[Object] = [
+            Object(r) for r in self._message.get("mention_roles", [])
+        ]
+        self.sticker_items: List[StickerItem] = [
+            StickerItem(state=self._state, data=s) for s in self._message.get("sticker_items", [])
+        ]
+        self.components: List[Component] = [
+            _component_factory(c) for c in self._message.get("components", [])
+        ]
+
+
 class MessageInteraction(Hashable):
     """Represents a message's interaction data.
 
@@ -570,6 +711,10 @@ class MessageInteraction(Hashable):
     user: Union[:class:`User`, :class:`Member`]
         The :class:`User` who invoked the interaction or :class:`Member` if the interaction
         occurred in a guild.
+
+    .. warning::
+        This class is deprecated, use :attr:`Message.interaction_metadata` instead.
+    .. deprecated:: 3.0
     """
 
     __slots__ = (
@@ -606,6 +751,130 @@ class MessageInteraction(Hashable):
         return utils.snowflake_time(self.id)
 
 
+class MessageInteractionMetadata(Hashable):
+    """Represents a message's interaction metadata.
+
+    A message's interaction metadata is a property of a message when the message
+    is a response to an interaction from any bot.
+
+    .. versionadded:: 3.0
+
+    .. container:: operations
+
+        .. describe:: x == y
+
+            Checks if two message interactions are equal.
+
+        .. describe:: x != y
+
+            Checks if two interaction messages are not equal.
+
+        .. describe:: hash(x)
+
+            Returns the message interaction's hash.
+
+    Attributes
+    ----------
+    data: Dict[:class:`str`, Any]
+        The raw data from the interaction metadata.
+    id: :class:`int`
+        The interaction's ID.
+    type: :class:`InteractionType`
+        The interaction type.
+    user: Union[:class:`User`, :class:`Member`]
+        The :class:`User` who invoked the interaction or :class:`Member` if the interaction
+        occurred in a guild and that member is cached.
+    authorizing_integration_owners: Dict[:class:`IntegrationType`, :class:`str`]
+        Mapping of installation contexts that the interaction was authorized for to related user or guild IDs.
+        You can find out about this field in the `official Discord documentation`__.
+
+        .. _integration_owners_docs: https://discord.com/developers/docs/interactions/receiving-and-responding#interaction-object-authorizing-integration-owners-object
+
+        __ integration_owners_docs_
+
+        .. versionadded:: 3.0
+    name: Optional[:class:`str`]
+        The name of the application command.
+    original_response_message_id: Optional[:class:`int`]
+        The ID of the original response message, present only on follow-up messages.
+    interacted_message_id: Optional[:class:`int`]
+        The ID of the message that contained the interactive component, present only on messages created from component interactions.
+    triggering_interaction_metadata: Optional[:class:`MessageInteractionMetadata`]
+        Metadata for the interaction that was used to open the modal, present only on modal submit interactions.
+    """
+
+    __slots__ = (
+        "_state",
+        "data",
+        "id",
+        "type",
+        "user",
+        "authorizing_integration_owners",
+        "name",
+        "original_response_message_id",
+        "interacted_message_id",
+        "triggering_interaction_metadata",
+    )
+
+    def __init__(
+        self,
+        *,
+        data: MessageInteractionMetadataPayload,
+        guild: Optional[Guild],
+        state: ConnectionState,
+    ) -> None:
+        self._state: ConnectionState = state
+
+        self.data: MessageInteractionMetadataPayload = data
+        self.id: int = int(data["id"])
+        self.type: int = data["type"]
+
+        # No member data is provided, retrieve from cache if possible
+        self.user = None if guild is None else guild.get_member(int(data["user"]["id"]))
+        if self.user is None:
+            self.user = self._state.create_user(data=data["user"])
+
+        self.authorizing_integration_owners: Dict[IntegrationType, int] = {
+            IntegrationType(int(integration_type)): int(details)
+            for integration_type, details in data["authorizing_integration_owners"].items()
+        }
+
+        self.name: Optional[str] = data.get("name")
+        self.original_response_message_id: Optional[int] = (
+            int(data["original_response_message_id"])
+            if "original_response_message_id" in data
+            else None
+        )
+        self.interacted_message_id: Optional[int] = (
+            int(data["interacted_message_id"]) if "interacted_message_id" in data else None
+        )
+        self.triggering_interaction_metadata: Optional[MessageInteractionMetadata] = (
+            MessageInteractionMetadata(
+                data=data["triggering_interaction_metadata"], guild=guild, state=state
+            )
+            if "triggering_interaction_metadata" in data
+            else None
+        )
+
+    def __repr__(self) -> str:
+        return f"<{self.__class__.__name__} id={self.id} type={self.type} user={self.user!r} name={self.name!r}>"
+
+    @property
+    def created_at(self) -> datetime.datetime:
+        """:class:`datetime.datetime`: The interaction's creation time in UTC."""
+        return utils.snowflake_time(self.id)
+
+    @property
+    def cached_original_response_message(self) -> Optional[Message]:
+        """Optional[:class:`~nextcord.Message`]: The original response message, if found in the internal message cache."""
+        return self._state._get_message(self.original_response_message_id)
+
+    @property
+    def cached_interacted_message(self) -> Optional[Message]:
+        """Optional[:class:`~nextcord.Message`]: The interacted message, if found in the internal message cache."""
+        return self._state._get_message(self.interacted_message_id)
+
+
 @flatten_handlers
 class Message(Hashable):
     r"""Represents a message from Discord.
@@ -723,6 +992,18 @@ class Message(Hashable):
         The guild that the message belongs to, if applicable.
     interaction: Optional[:class:`MessageInteraction`]
         The interaction data of a message, if applicable.
+
+        .. warning::
+            This field is deprecated, use ``interaction_metadata`` instead.
+        .. deprecated:: 3.0
+    interaction_metadata: Optional[:class:`MessageInteractionMetadata`]
+        The interaction metadata of a message. Present if the message is sent as a result of an interaction.
+
+        .. versionadded:: 3.0
+    snapshots: List[:class:`MessageSnapshot`]
+        A list of message snapshots that the message contains.
+
+        .. versionadded:: 3.0
     """
 
     __slots__ = (
@@ -742,6 +1023,7 @@ class Message(Hashable):
         "embeds",
         "id",
         "interaction",
+        "interaction_metadata",
         "mentions",
         "author",
         "attachments",
@@ -756,7 +1038,9 @@ class Message(Hashable):
         "activity",
         "stickers",
         "components",
+        "_background_tasks",
         "guild",
+        "snapshots",
     )
 
     if TYPE_CHECKING:
@@ -804,6 +1088,7 @@ class Message(Hashable):
         self.components: List[Component] = [
             _component_factory(d) for d in data.get("components", [])
         ]
+        self._background_tasks: Set[asyncio.Task[None]] = set()
 
         try:
             # if the channel doesn't have a guild attribute, we handle that
@@ -814,9 +1099,16 @@ class Message(Hashable):
             else:
                 self.guild = None
 
-        if thread_data := data.get("thread"):
-            if not self.thread and isinstance(self.guild, Guild):
-                self.guild._store_thread(thread_data)
+        if (
+            (thread_data := data.get("thread"))
+            and not self.thread
+            and isinstance(self.guild, Guild)
+        ):
+            self.guild._store_thread(thread_data)
+
+        self.snapshots: List[MessageSnapshot] = [
+            MessageSnapshot(state=self._state, data=s) for s in data.get("message_snapshots", [])
+        ]
 
         try:
             ref = data["message_reference"]
@@ -852,6 +1144,13 @@ class Message(Hashable):
             if "interaction" in data
             else None
         )
+        self.interaction_metadata: Optional[MessageInteractionMetadata] = (
+            MessageInteractionMetadata(
+                data=data["interaction_metadata"], guild=self.guild, state=self._state
+            )
+            if "interaction_metadata" in data
+            else None
+        )
 
     def __repr__(self) -> str:
         name = self.__class__.__name__
@@ -906,12 +1205,12 @@ class Message(Hashable):
 
     def _clear_emoji(self, emoji) -> Optional[Reaction]:
         to_check = str(emoji)
-        for index, reaction in enumerate(self.reactions):
+        for index, reaction in enumerate(self.reactions):  # noqa: B007
             if str(reaction.emoji) == to_check:
                 break
         else:
             # didn't find anything so just return
-            return
+            return None
 
         del self.reactions[index]
         return reaction
@@ -931,10 +1230,8 @@ class Message(Hashable):
 
         # clear the cached properties
         for attr in self._CACHED_SLOTS:
-            try:
+            with contextlib.suppress(AttributeError):
                 delattr(self, attr)
-            except AttributeError:
-                pass
 
     def _handle_edited_timestamp(self, value: str) -> None:
         self._edited_timestamp = utils.parse_time(value)
@@ -1080,21 +1377,17 @@ class Message(Hashable):
             respectively, along with this function.
         """
 
-        # fmt: off
         transformations = {
-            re.escape(f'<#{channel.id}>'): '#' + channel.name
-            for channel in self.channel_mentions
+            re.escape(f"<#{channel.id}>"): "#" + channel.name for channel in self.channel_mentions
         }
 
         mention_transforms = {
-            re.escape(f'<@{member.id}>'): '@' + member.display_name
-            for member in self.mentions
+            re.escape(f"<@{member.id}>"): "@" + member.display_name for member in self.mentions
         }
 
         # add the <@!user_id> cases as well..
         second_mention_transforms = {
-            re.escape(f'<@!{member.id}>'): '@' + member.display_name
-            for member in self.mentions
+            re.escape(f"<@!{member.id}>"): "@" + member.display_name for member in self.mentions
         }
 
         transformations.update(mention_transforms)
@@ -1102,13 +1395,10 @@ class Message(Hashable):
 
         if self.guild is not None:
             role_transforms = {
-                re.escape(f'<@&{role.id}>'): '@' + role.name
-                for role in self.role_mentions
+                re.escape(f"<@&{role.id}>"): "@" + role.name for role in self.role_mentions
             }
             transformations.update(role_transforms)
 
-        # fmt: on
-
         def repl(obj):
             return transformations.get(re.escape(obj.group(0)), "")
 
@@ -1172,14 +1462,12 @@ class Message(Hashable):
         if self.type is MessageType.recipient_add:
             if self.channel.type is ChannelType.group:
                 return f"{self.author.name} added {self.mentions[0].name} to the group."
-            else:
-                return f"{self.author.name} added {self.mentions[0].name} to the thread."
+            return f"{self.author.name} added {self.mentions[0].name} to the thread."
 
         if self.type is MessageType.recipient_remove:
             if self.channel.type is ChannelType.group:
                 return f"{self.author.name} removed {self.mentions[0].name} from the group."
-            else:
-                return f"{self.author.name} removed {self.mentions[0].name} from the thread."
+            return f"{self.author.name} removed {self.mentions[0].name} from the thread."
 
         if self.type is MessageType.channel_name_change:
             return f"{self.author.name} changed the channel name: **{self.content}**"
@@ -1213,26 +1501,22 @@ class Message(Hashable):
         if self.type is MessageType.premium_guild_subscription:
             if not self.content:
                 return f"{self.author.name} just boosted the server!"
-            else:
-                return f"{self.author.name} just boosted the server **{self.content}** times!"
+            return f"{self.author.name} just boosted the server **{self.content}** times!"
 
         if self.type is MessageType.premium_guild_tier_1:
             if not self.content:
                 return f"{self.author.name} just boosted the server! {self.guild} has achieved **Level 1!**"
-            else:
-                return f"{self.author.name} just boosted the server **{self.content}** times! {self.guild} has achieved **Level 1!**"
+            return f"{self.author.name} just boosted the server **{self.content}** times! {self.guild} has achieved **Level 1!**"
 
         if self.type is MessageType.premium_guild_tier_2:
             if not self.content:
                 return f"{self.author.name} just boosted the server! {self.guild} has achieved **Level 2!**"
-            else:
-                return f"{self.author.name} just boosted the server **{self.content}** times! {self.guild} has achieved **Level 2!**"
+            return f"{self.author.name} just boosted the server **{self.content}** times! {self.guild} has achieved **Level 2!**"
 
         if self.type is MessageType.premium_guild_tier_3:
             if not self.content:
                 return f"{self.author.name} just boosted the server! {self.guild} has achieved **Level 3!**"
-            else:
-                return f"{self.author.name} just boosted the server **{self.content}** times! {self.guild} has achieved **Level 3!**"
+            return f"{self.author.name} just boosted the server **{self.content}** times! {self.guild} has achieved **Level 3!**"
 
         if self.type is MessageType.channel_follow_add:
             return f"{self.author.name} has added {self.content} to this channel"
@@ -1269,6 +1553,20 @@ class Message(Hashable):
         if self.type is MessageType.guild_invite_reminder:
             return "Wondering who to invite?\nStart by inviting anyone who can help you build the server!"
 
+        if self.type is MessageType.stage_start:
+            return f"{self.author.display_name} started {self.content}"
+
+        if self.type is MessageType.stage_end:
+            return f"{self.author.display_name} ended {self.content}"
+
+        if self.type is MessageType.stage_speaker:
+            return f"{self.author.display_name} is now a speaker."
+
+        if self.type is MessageType.stage_topic:
+            return f"{self.author.display_name} changed the Stage topic: {self.content}"
+
+        return None
+
     async def delete(self, *, delay: Optional[float] = None) -> None:
         """|coro|
 
@@ -1300,12 +1598,12 @@ class Message(Hashable):
 
             async def delete(delay: float) -> None:
                 await asyncio.sleep(delay)
-                try:
+                with contextlib.suppress(HTTPException):
                     await self._state.http.delete_message(self.channel.id, self.id)
-                except HTTPException:
-                    pass
 
-            asyncio.create_task(delete(delay))
+            task = asyncio.create_task(delete(delay))
+            self._background_tasks.add(task)
+            task.add_done_callback(self._background_tasks.discard)
         else:
             await self._state.http.delete_message(self.channel.id, self.id)
 
@@ -1321,8 +1619,7 @@ class Message(Hashable):
         allowed_mentions: Optional[AllowedMentions] = ...,
         view: Optional[View] = ...,
         file: Optional[File] = ...,
-    ) -> Message:
-        ...
+    ) -> Message: ...
 
     @overload
     async def edit(
@@ -1336,8 +1633,7 @@ class Message(Hashable):
         allowed_mentions: Optional[AllowedMentions] = ...,
         view: Optional[View] = ...,
         file: Optional[File] = ...,
-    ) -> Message:
-        ...
+    ) -> Message: ...
 
     @overload
     async def edit(
@@ -1351,8 +1647,7 @@ class Message(Hashable):
         allowed_mentions: Optional[AllowedMentions] = ...,
         view: Optional[View] = ...,
         files: Optional[List[File]] = ...,
-    ) -> Message:
-        ...
+    ) -> Message: ...
 
     @overload
     async def edit(
@@ -1366,8 +1661,7 @@ class Message(Hashable):
         allowed_mentions: Optional[AllowedMentions] = ...,
         view: Optional[View] = ...,
         files: Optional[List[File]] = ...,
-    ) -> Message:
-        ...
+    ) -> Message: ...
 
     async def edit(
         self,
@@ -1439,6 +1733,8 @@ class Message(Hashable):
 
         Raises
         ------
+        NotFound
+            The message was not found.
         HTTPException
             Editing the message failed.
         Forbidden
@@ -1481,14 +1777,13 @@ class Message(Hashable):
         if allowed_mentions is MISSING:
             if self._state.allowed_mentions is not None and self.author.id == self._state.self_id:
                 payload["allowed_mentions"] = self._state.allowed_mentions.to_dict()
-        else:
-            if allowed_mentions is not None:
-                if self._state.allowed_mentions is not None:
-                    payload["allowed_mentions"] = self._state.allowed_mentions.merge(
-                        allowed_mentions
-                    ).to_dict()
-                else:
-                    payload["allowed_mentions"] = allowed_mentions.to_dict()
+        elif allowed_mentions is not None:
+            if self._state.allowed_mentions is not None:
+                payload["allowed_mentions"] = self._state.allowed_mentions.merge(
+                    allowed_mentions
+                ).to_dict()
+            else:
+                payload["allowed_mentions"] = allowed_mentions.to_dict()
 
         if attachments is not MISSING:
             payload["attachments"] = [a.to_dict() for a in attachments]
@@ -1508,7 +1803,7 @@ class Message(Hashable):
         data = await self._state.http.edit_message(self.channel.id, self.id, **payload)
         message = Message(state=self._state, channel=self.channel, data=data)
 
-        if view and not view.is_finished():
+        if view and not view.is_finished() and view.prevent_update:
             self._state.store_view(view, self.id)
 
         if delete_after is not None:
@@ -1788,6 +2083,31 @@ class Message(Hashable):
 
         return await self.channel.send(content, reference=self, **kwargs)
 
+    async def forward(self, channel: Messageable) -> Message:
+        """Forward this message to a channel.
+
+        .. note::
+            It is not possible to forward messages through interactions.
+            It is only possible to forward a message to a channel as a message.
+
+        Parameters
+        ----------
+        channel: :class:`~nextcord.Messageable`
+            The channel to forward this message.
+
+        Raises
+        ------
+        ~nextcord.HTTPException
+            Forwarding/sending the message failed.
+        ~nextcord.Forbidden
+            You do not have the proper permissions to send the message.
+
+        .. versionadded:: 3.0
+        """
+        return await channel.send(
+            reference=MessageReference.from_message(self, type=MessageReferenceType.forward),
+        )
+
     def to_reference(self, *, fail_if_not_exists: bool = True) -> MessageReference:
         """Creates a :class:`~nextcord.MessageReference` from the current message.
 
@@ -1895,7 +2215,7 @@ class PartialMessage(Hashable):
 
     # Also needed for duck typing purposes
     # n.b. not exposed
-    pinned = property(None, lambda x, y: None)
+    pinned = property(None, lambda _, __: None)
 
     def __repr__(self) -> str:
         return f"<PartialMessage id={self.id} channel={self.channel!r}>"
@@ -2060,6 +2380,7 @@ class PartialMessage(Hashable):
         if fields:
             # data isn't unbound
             msg = self._state.create_message(channel=self.channel, data=data)  # type: ignore
-            if view and not view.is_finished():
+            if view and not view.is_finished() and view.prevent_update:
                 self._state.store_view(view, self.id)
             return msg
+        return None
