@@ -503,7 +503,6 @@ def _sticker_factory(
     value = try_enum(StickerType, sticker_type)
     if value == StickerType.standard:
         return StandardSticker, value
-    elif value == StickerType.guild:
+    if value == StickerType.guild:
         return GuildSticker, value
-    else:
-        return Sticker, value
+    return Sticker, value
