@@ -19,6 +19,8 @@ if TYPE_CHECKING:
 
 
 ApplicationCommandType = Literal[1, 2, 3]
+IntegrationType = Literal[0, 1]
+InteractionContextType = Literal[0, 1, 2]
 
 
 class ApplicationCommand(TypedDict):
@@ -32,8 +34,9 @@ class ApplicationCommand(TypedDict):
     guild_id: NotRequired[Snowflake]
     options: NotRequired[List[ApplicationCommandOption]]
     default_permission: NotRequired[bool]
-    dm_permission: NotRequired[bool]
     nsfw: NotRequired[bool]
+    integration_types: NotRequired[List[IntegrationType]]
+    contexts: NotRequired[List[InteractionContextType]]
     name_localizations: NotRequired[Dict[str, str]]
     description_localizations: NotRequired[Dict[str, str]]
 
@@ -194,6 +197,7 @@ class ModalSubmitInteractionData(TypedDict):
 InteractionData = Union[
     ApplicationCommandInteractionData, ComponentInteractionData, ModalSubmitInteractionData
 ]
+AuthorizingIntegrationOwners = Dict[str, str]
 
 
 class Interaction(TypedDict):
@@ -211,6 +215,8 @@ class Interaction(TypedDict):
     locale: NotRequired[str]
     guild_locale: NotRequired[str]
     app_permissions: NotRequired[str]
+    authorizing_integration_owners: NotRequired[AuthorizingIntegrationOwners]
+    context: NotRequired[InteractionContextType]
 
 
 class InteractionApplicationCommandCallbackData(TypedDict, total=False):
@@ -238,6 +244,17 @@ class MessageInteraction(TypedDict):
     member: NotRequired[Member]
 
 
+class MessageInteractionMetadata(TypedDict):
+    id: Snowflake
+    type: InteractionType
+    user: User
+    authorizing_integration_owners: AuthorizingIntegrationOwners
+    name: NotRequired[str]
+    original_response_message_id: NotRequired[Snowflake]
+    interacted_message_id: NotRequired[Snowflake]
+    triggering_interaction_metadata: NotRequired[MessageInteractionMetadata]
+
+
 class EditApplicationCommand(TypedDict):
     name: str
     default_permission: bool
