@@ -19,7 +19,7 @@ from typing import (
     Iterator,
     List,
     Optional,
-    Sequence,
+    Set,
     Tuple,
 )
 
@@ -138,6 +138,13 @@ class View:
         Whether or not to automatically defer the component interaction when the callback
         completes without responding to the interaction. Set this to ``False`` if you want to
         handle view interactions outside of the callback.
+    prevent_update: :class:`bool` = True
+        This option only affects persistent views.
+        Whether or not to store the view separately for each message.
+        The stored views are not automatically cleared, and can cause issues if
+        you run the bot continously for long periods of time if views are not properly stopped.
+        Setting this to False will force the client to find a persistent view added with
+        `Bot.add_view` and not store the view separately.
     """
 
     __discord_ui_view__: ClassVar[bool] = True
@@ -146,18 +153,27 @@ class View:
     def __init_subclass__(cls) -> None:
         children: List[ItemCallbackType] = []
         for base in reversed(cls.__mro__):
-            for member in base.__dict__.values():
-                if hasattr(member, "__discord_ui_model_type__"):
-                    children.append(member)
+            children.extend(
+                member
+                for member in base.__dict__.values()
+                if hasattr(member, "__discord_ui_model_type__")
+            )
 
         if len(children) > 25:
             raise TypeError("View cannot have more than 25 children")
 
         cls.__view_children_items__ = children
 
-    def __init__(self, *, timeout: Optional[float] = 180.0, auto_defer: bool = True) -> None:
+    def __init__(
+        self,
+        *,
+        timeout: Optional[float] = 180.0,
+        auto_defer: bool = True,
+        prevent_update: bool = True,
+    ) -> None:
         self.timeout = timeout
         self.auto_defer = auto_defer
+        self.prevent_update = True if timeout else prevent_update
         self.children: List[Item] = []
         for func in self.__view_children_items__:
             item: Item = func.__discord_ui_model_type__(**func.__discord_ui_model_kwargs__)
@@ -172,6 +188,7 @@ class View:
         self.__cancel_callback: Optional[Callable[[View], None]] = None
         self.__timeout_expiry: Optional[float] = None
         self.__timeout_task: Optional[asyncio.Task[None]] = None
+        self.__background_tasks: Set[asyncio.Task[None]] = set()
         self.__stopped: asyncio.Future[bool] = loop.create_future()
 
     def __repr__(self) -> str:
@@ -181,7 +198,7 @@ class View:
         while True:
             # Guard just in case someone changes the value of the timeout at runtime
             if self.timeout is None:
-                return
+                return None
 
             if self.__timeout_expiry is None:
                 return self._dispatch_timeout()
@@ -336,7 +353,6 @@ class View:
 
         A callback that is called when a view's timeout elapses without being explicitly stopped.
         """
-        pass
 
     async def on_error(self, error: Exception, item: Item, interaction: Interaction) -> None:
         """|coro|
@@ -355,7 +371,7 @@ class View:
         interaction: :class:`~nextcord.Interaction`
             The interaction that led to the failure.
         """
-        print(f"Ignoring exception in view {self} for item {item}:", file=sys.stderr)
+        print(f"Ignoring exception in view {self} for item {item}:", file=sys.stderr)  # noqa: T201
         traceback.print_exception(error.__class__, error, error.__traceback__, file=sys.stderr)
 
     async def _scheduled_task(self, item: Item, interaction: Interaction):
@@ -365,7 +381,7 @@ class View:
 
             allow = await self.interaction_check(interaction)
             if not allow:
-                return
+                return None
 
             await item.callback(interaction)
             if (
@@ -391,25 +407,25 @@ class View:
         if self.__stopped.done():
             return
 
-        asyncio.create_task(self.on_timeout(), name=f"discord-ui-view-timeout-{self.id}")
+        task = asyncio.create_task(self.on_timeout(), name=f"discord-ui-view-timeout-{self.id}")
+        self.__background_tasks.add(task)
+        task.add_done_callback(self.__background_tasks.discard)
         self.__stopped.set_result(True)
 
     def _dispatch_item(self, item: Item, interaction: Interaction) -> None:
         if self.__stopped.done():
             return
 
-        asyncio.create_task(
+        task = asyncio.create_task(
             self._scheduled_task(item, interaction), name=f"discord-ui-view-dispatch-{self.id}"
         )
+        self.__background_tasks.add(task)
+        task.add_done_callback(self.__background_tasks.discard)
 
     def refresh(self, components: List[Component]) -> None:
-        # fmt: off
         old_state: Dict[str, Item[Any]] = {
-            item.custom_id: item  # type: ignore
-            for item in self.children
-            if item.is_dispatchable()
+            item.custom_id: item for item in self.children if item.is_dispatchable()  # type: ignore
         }
-        # fmt: on
 
         for component in _walk_all_components(components):
             custom_id = getattr(component, "custom_id", None)
@@ -477,23 +493,22 @@ class View:
 
 class ViewStore:
     def __init__(self, state: ConnectionState) -> None:
-        # (component_type, message_id, custom_id): (View, Item)
         self._views: Dict[Tuple[int, Optional[int], str], Tuple[View, Item]] = {}
-        # message_id: View
+        """(component_type, message_id, custom_id): (View, Item)"""
         self._synced_message_views: Dict[int, View] = {}
+        """message_id: View"""
         self._state: ConnectionState = state
 
-    @property
-    def persistent_views(self) -> Sequence[View]:
-        # fmt: off
-        views = {
-            view.id: view
-            for (_, (view, _)) in self._views.items()
-            if view.is_persistent()
-        }
-        # fmt: on
+    def all_views(self) -> List[View]:
+        # Create a unique list of views, as _views stores the same view multiple times,
+        # one for each dispatchable item.
+        views = {view.id: view for view, _ in self._views.values()}
         return list(views.values())
 
+    def views(self, persistent: bool = True) -> List[View]:
+        views = self.all_views()
+        return [v for v in views if v.is_persistent() ^ (not persistent)]
+
     def __verify_integrity(self) -> None:
         to_remove: List[Tuple[int, Optional[int], str]] = []
         for k, (view, _) in self._views.items():
