@@ -12,13 +12,13 @@ import functools
 import inspect
 import json
 import re
-import sys
 import unicodedata
 import warnings
 from base64 import b64encode
 from bisect import bisect_left
 from inspect import isawaitable as _isawaitable, signature as _signature
 from operator import attrgetter
+from types import UnionType
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -42,6 +42,7 @@ from typing import (
     overload,
 )
 
+from .enums import IntegrationType
 from .errors import InvalidArgument
 from .file import File
 
@@ -65,18 +66,6 @@ else:
 
 HAS_ORJSON = _orjson_defined
 
-
-PY_310 = sys.version_info >= (3, 10)
-
-
-if PY_310:
-    from types import UnionType  # type: ignore
-
-    # UnionType is the annotation origin when doing Python 3.10 unions. Example: "str | None"
-else:
-    UnionType = None
-
-
 if TYPE_CHECKING:
     from typing_extensions import Self
 
@@ -97,6 +86,8 @@ __all__ = (
     "parse_raw_channel_mentions",
     "as_chunks",
     "format_dt",
+    "format_ts",
+    "cached_property",
 )
 
 DISCORD_EPOCH = 1420070400000
@@ -122,7 +113,7 @@ MISSING: Any = _MissingSentinel()
 class _cached_property:
     def __init__(self, function: Callable[..., Any]) -> None:
         self.function = function
-        self.__doc__ = getattr(function, "__doc__")
+        self.__doc__ = function.__doc__
 
     def __get__(self, instance: Any, owner: Any):
         if instance is None:
@@ -135,7 +126,7 @@ class _cached_property:
 
 
 if TYPE_CHECKING:
-    from functools import cached_property as cached_property
+    from functools import cached_property
 
     from typing_extensions import ParamSpec
 
@@ -161,15 +152,13 @@ class CachedSlotProperty(Generic[T, T_co]):
     def __init__(self, name: str, function: Callable[[T], T_co]) -> None:
         self.name = name
         self.function = function
-        self.__doc__ = getattr(function, "__doc__")
+        self.__doc__ = function.__doc__
 
     @overload
-    def __get__(self, instance: None, owner: Type[T]) -> CachedSlotProperty[T, T_co]:
-        ...
+    def __get__(self, instance: None, owner: Type[T]) -> CachedSlotProperty[T, T_co]: ...
 
     @overload
-    def __get__(self, instance: T, owner: Type[T]) -> T_co:
-        ...
+    def __get__(self, instance: T, owner: Type[T]) -> T_co: ...
 
     def __get__(self, instance: Optional[T], owner: Type[T]) -> Any:
         if instance is None:
@@ -209,7 +198,10 @@ class SequenceProxy(Sequence[T_co], Generic[T_co]):
     def __init__(self, proxied: Sequence[T_co]) -> None:
         self.__proxied = proxied
 
-    def __getitem__(self, idx: int) -> T_co:
+    # Likely Pyright bug. The base method doesn't seem to even have a return type.
+    # base method returns type "Sequence[T_co@SequenceProxy]"
+    # override returns type "T_co@SequenceProxy"
+    def __getitem__(self, idx: int) -> T_co:  # pyright: ignore
         return self.__proxied[idx]
 
     def __len__(self) -> int:
@@ -232,18 +224,15 @@ class SequenceProxy(Sequence[T_co], Generic[T_co]):
 
 
 @overload
-def parse_time(timestamp: None) -> None:
-    ...
+def parse_time(timestamp: None) -> None: ...
 
 
 @overload
-def parse_time(timestamp: str) -> datetime.datetime:
-    ...
+def parse_time(timestamp: str) -> datetime.datetime: ...
 
 
 @overload
-def parse_time(timestamp: Optional[str]) -> Optional[datetime.datetime]:
-    ...
+def parse_time(timestamp: Optional[str]) -> Optional[datetime.datetime]: ...
 
 
 def parse_time(timestamp: Optional[str]) -> Optional[datetime.datetime]:
@@ -290,6 +279,7 @@ def oauth_url(
     redirect_uri: str = MISSING,
     scopes: Iterable[str] = MISSING,
     disable_guild_select: bool = False,
+    integration_type: IntegrationType = MISSING,
 ) -> str:
     """A helper function that returns the OAuth2 URL for inviting the bot
     into guilds.
@@ -313,6 +303,10 @@ def oauth_url(
         Whether to disallow the user from changing the guild dropdown.
 
         .. versionadded:: 2.0
+    integration_type: :class:`~nextcord.IntegrationType`
+        The integration type (otherwise known as installation context) that the invite is for.
+
+        .. versionadded:: 3.0
 
     Returns
     -------
@@ -331,6 +325,8 @@ def oauth_url(
         url += "&response_type=code&" + urlencode({"redirect_uri": redirect_uri})
     if disable_guild_select:
         url += "&disable_guild_select=true"
+    if integration_type is not MISSING:
+        url += f"&integration_type={integration_type.value}"
     return url
 
 
@@ -412,8 +408,7 @@ def _key_fmt(key: str) -> str:
 
     if key.startswith("__") and key.endswith("__"):
         return re.sub(r"_{6}", "__.__", key)
-    else:
-        return re.sub(r"__(?!_)", ".", key)
+    return re.sub(r"__(?!_)", ".", key)
 
 
 def get(iterable: Iterable[T], **attrs: Any) -> Optional[T]:
@@ -482,7 +477,7 @@ def get(iterable: Iterable[T], **attrs: Any) -> Optional[T]:
 
 
 def unique(iterable: Iterable[T]) -> List[T]:
-    return [x for x in dict.fromkeys(iterable)]
+    return list(dict.fromkeys(iterable))
 
 
 def get_as_snowflake(data: Any, key: str) -> Optional[int]:
@@ -497,14 +492,14 @@ def get_as_snowflake(data: Any, key: str) -> Optional[int]:
 def _get_mime_type_for_image(data: bytes) -> str:
     if data.startswith(b"\x89\x50\x4E\x47\x0D\x0A\x1A\x0A"):
         return "image/png"
-    elif data[0:3] == b"\xff\xd8\xff" or data[6:10] in (b"JFIF", b"Exif"):
+    if data[0:3] == b"\xff\xd8\xff" or data[6:10] in (b"JFIF", b"Exif"):
         return "image/jpeg"
-    elif data.startswith((b"\x47\x49\x46\x38\x37\x61", b"\x47\x49\x46\x38\x39\x61")):
+    if data.startswith((b"\x47\x49\x46\x38\x37\x61", b"\x47\x49\x46\x38\x39\x61")):
         return "image/gif"
-    elif data.startswith(b"RIFF") and data[8:12] == b"WEBP":
+    if data.startswith(b"RIFF") and data[8:12] == b"WEBP":
         return "image/webp"
-    else:
-        raise InvalidArgument("Unsupported image type given")
+
+    raise InvalidArgument("Unsupported image type given")
 
 
 def _bytes_to_base64_data(data: bytes) -> str:
@@ -519,10 +514,9 @@ async def obj_to_base64_data(obj: Optional[Union[bytes, Attachment, Asset, File]
         return obj
     if isinstance(obj, bytes):
         return _bytes_to_base64_data(obj)
-    elif isinstance(obj, File):
+    if isinstance(obj, File):
         return _bytes_to_base64_data(obj.fp.read())
-    else:
-        return _bytes_to_base64_data(await obj.read())
+    return _bytes_to_base64_data(await obj.read())
 
 
 def parse_ratelimit_header(request: Any, *, use_clock: bool = False) -> float:
@@ -532,8 +526,7 @@ def parse_ratelimit_header(request: Any, *, use_clock: bool = False) -> float:
         now = datetime.datetime.now(utc)
         reset = datetime.datetime.fromtimestamp(float(request.headers["X-Ratelimit-Reset"]), utc)
         return (reset - now).total_seconds()
-    else:
-        return float(reset_after)
+    return float(reset_after)
 
 
 async def maybe_coroutine(
@@ -542,10 +535,9 @@ async def maybe_coroutine(
     value = f(*args, **kwargs)
     if _isawaitable(value):
         return await value
-    else:
-        return value  # type: ignore
-        # type ignored as `_isawaitable` provides `TypeGuard[Awaitable[Any]]`
-        # yet we need a more specific type guard
+    return value  # type: ignore
+    # type ignored as `_isawaitable` provides `TypeGuard[Awaitable[Any]]`
+    # yet we need a more specific type guard
 
 
 async def async_all(
@@ -566,7 +558,7 @@ async def sane_wait_for(
     done, pending = await asyncio.wait(ensured, timeout=timeout, return_when=asyncio.ALL_COMPLETED)
 
     if len(pending) != 0:
-        raise asyncio.TimeoutError()
+        raise asyncio.TimeoutError
 
     return done
 
@@ -646,8 +638,7 @@ class SnowflakeList(array.array):  # pyright: ignore[reportMissingTypeArgument]
 
     if TYPE_CHECKING:
 
-        def __init__(self, data: Iterable[int], *, is_sorted: bool = False) -> None:
-            ...
+        def __init__(self, data: Iterable[int], *, is_sorted: bool = False) -> None: ...
 
     def __new__(cls, data: Iterable[int], *, is_sorted: bool = False) -> Self:
         return array.array.__new__(cls, "Q", data if is_sorted else sorted(data))  # type: ignore
@@ -700,11 +691,12 @@ def resolve_invite(invite: Union[Invite, str]) -> str:
             raise NotImplementedError("Can not resolve the invite if the code is `None`")
 
         return invite.code
-    else:
-        rx = r"(?:https?\:\/\/)?discord(?:\.gg|(?:app)?\.com\/invite)\/(.+)"
-        m = re.match(rx, invite)
-        if m:
-            return m.group(1)
+
+    rx = r"(?:https?\:\/\/)?discord(?:\.gg|(?:app)?\.com\/invite)\/(.+)"
+    m = re.match(rx, invite)
+    if m:
+        return m.group(1)
+
     return invite
 
 
@@ -728,11 +720,10 @@ def resolve_template(code: Union[Template, str]) -> str:
 
     if isinstance(code, Template):
         return code.code
-    else:
-        rx = r"(?:https?\:\/\/)?discord(?:\.new|(?:app)?\.com\/template)\/(.+)"
-        m = re.match(rx, code)
-        if m:
-            return m.group(1)
+    rx = r"(?:https?\:\/\/)?discord(?:\.new|(?:app)?\.com\/template)\/(.+)"
+    m = re.match(rx, code)
+    if m:
+        return m.group(1)
     return code
 
 
@@ -783,7 +774,7 @@ def remove_markdown(text: str, *, ignore_links: bool = True) -> str:
     regex = _MARKDOWN_STOCK_REGEX
     if ignore_links:
         regex = f"(?:{_URL_REGEX}|{regex})"
-    return re.sub(regex, replacement, text, 0, re.MULTILINE)
+    return re.sub(regex, replacement, text, count=0, flags=re.MULTILINE)
 
 
 def escape_markdown(text: str, *, as_needed: bool = False, ignore_links: bool = True) -> str:
@@ -823,10 +814,10 @@ def escape_markdown(text: str, *, as_needed: bool = False, ignore_links: bool =
         regex = _MARKDOWN_STOCK_REGEX
         if ignore_links:
             regex = f"(?:{_URL_REGEX}|{regex})"
-        return re.sub(regex, replacement, text, 0, re.MULTILINE)
-    else:
-        text = re.sub(r"\\", r"\\\\", text)
-        return _MARKDOWN_ESCAPE_REGEX.sub(r"\\\1", text)
+        return re.sub(regex, replacement, text, count=0, flags=re.MULTILINE)
+
+    text = re.sub(r"\\", r"\\\\", text)
+    return _MARKDOWN_ESCAPE_REGEX.sub(r"\\\1", text)
 
 
 def escape_mentions(text: str) -> str:
@@ -946,13 +937,11 @@ async def _achunk(iterator: AsyncIterator[T], max_size: int) -> AsyncIterator[Li
 
 
 @overload
-def as_chunks(iterator: Iterator[T], max_size: int) -> Iterator[List[T]]:
-    ...
+def as_chunks(iterator: Iterator[T], max_size: int) -> Iterator[List[T]]: ...
 
 
 @overload
-def as_chunks(iterator: AsyncIterator[T], max_size: int) -> AsyncIterator[List[T]]:
-    ...
+def as_chunks(iterator: AsyncIterator[T], max_size: int) -> AsyncIterator[List[T]]: ...
 
 
 def as_chunks(iterator: _Iter[T], max_size: int) -> _Iter[List[T]]:
@@ -998,7 +987,7 @@ def flatten_literal_params(parameters: Iterable[Any]) -> Tuple[Any, ...]:
 
 def normalise_optional_params(parameters: Iterable[Any]) -> Tuple[Any, ...]:
     none_cls = type(None)
-    return tuple(p for p in parameters if p is not none_cls) + (none_cls,)
+    return (*tuple(p for p in parameters if p is not none_cls), none_cls)
 
 
 def evaluate_annotation(
@@ -1017,7 +1006,8 @@ def evaluate_annotation(
     if implicit_str and isinstance(tp, str):
         if tp in cache:
             return cache[tp]
-        evaluated = eval(tp, globals, locals)
+        evaluated = eval(tp, globals, locals)  # noqa: S307
+        # eval() here uses the type annotation from the user, eval is all under control.
         cache[tp] = evaluated
         return evaluate_annotation(evaluated, globals, locals, cache)
 
@@ -1026,7 +1016,7 @@ def evaluate_annotation(
         is_literal = False
         args = tp.__args__
         if not hasattr(tp, "__origin__"):
-            if PY_310 and tp.__class__ is UnionType:
+            if tp.__class__ is UnionType:
                 converted = Union[args]  # type: ignore
                 return evaluate_annotation(converted, globals, locals, cache)
 
@@ -1038,8 +1028,6 @@ def evaluate_annotation(
             except ValueError:
                 pass
         if tp.__origin__ is Literal:
-            if not PY_310:
-                args = flatten_literal_params(tp.__args__)
             implicit_str = False
             is_literal = True
 
@@ -1126,9 +1114,54 @@ def format_dt(dt: datetime.datetime, /, style: Optional[TimestampStyle] = None)
     """
     if not isinstance(dt, datetime.datetime):  # pyright: ignore[reportUnnecessaryIsInstance]
         raise InvalidArgument("'dt' must be of type 'datetime.datetime'")
+    return format_ts(int(dt.timestamp()), style=style)
+
+
+def format_ts(ts: int, /, style: Optional[TimestampStyle] = None) -> str:
+    """A helper function to format a Unix timestamp as an :class:`int` for presentation within Discord.
+
+    This allows for a locale-independent way of presenting data using Discord specific Markdown.
+
+    +-------------+----------------------------+-----------------+
+    |    Style    |       Example Output       |   Description   |
+    +=============+============================+=================+
+    | t           | 22:57                      | Short Time      |
+    +-------------+----------------------------+-----------------+
+    | T           | 22:57:58                   | Long Time       |
+    +-------------+----------------------------+-----------------+
+    | d           | 17/05/2016                 | Short Date      |
+    +-------------+----------------------------+-----------------+
+    | D           | 17 May 2016                | Long Date       |
+    +-------------+----------------------------+-----------------+
+    | f (default) | 17 May 2016 22:57          | Short Date Time |
+    +-------------+----------------------------+-----------------+
+    | F           | Tuesday, 17 May 2016 22:57 | Long Date Time  |
+    +-------------+----------------------------+-----------------+
+    | R           | 5 years ago                | Relative Time   |
+    +-------------+----------------------------+-----------------+
+
+    Note that the exact output depends on the user's locale setting in the client. The example output
+    presented is using the ``en-GB`` locale.
+
+    .. versionadded:: 2.6
+
+    Parameters
+    ----------
+    ts: :class:`int`
+        The Unix timestamp to format.
+    style: :class:`str`
+        The style to format the timestamp with.
+
+    Returns
+    -------
+    :class:`str`
+        The formatted string.
+    """
+    if not isinstance(ts, int):  # pyright: ignore[reportUnnecessaryIsInstance]
+        raise InvalidArgument("'ts' must be of type 'int'")
     if style is None:
-        return f"<t:{int(dt.timestamp())}>"
-    return f"<t:{int(dt.timestamp())}:{style}>"
+        return f"<t:{ts}>"
+    return f"<t:{ts}:{style}>"
 
 
 _FUNCTION_DESCRIPTION_REGEX = re.compile(r"\A(?:.|\n)+?(?=\Z|\r?\n\r?\n)", re.MULTILINE)
