@@ -8,6 +8,7 @@
 
 from __future__ import annotations
 
+import contextlib
 import json
 import logging
 import re
@@ -16,11 +17,12 @@ import time
 from types import TracebackType
 from typing import TYPE_CHECKING, Any, Dict, List, Literal, Optional, Tuple, Type, Union, overload
 from urllib.parse import quote as urlquote
+from weakref import WeakValueDictionary
 
 from .. import utils
 from ..channel import PartialMessageable
 from ..errors import DiscordServerError, Forbidden, HTTPException, InvalidArgument, NotFound
-from ..http import Route
+from ..http import _USER_AGENT, Route
 from ..message import Attachment, Message
 from .async_ import BaseWebhook, _WebhookState, handle_message_parameters
 
@@ -36,12 +38,12 @@ if TYPE_CHECKING:
     from ..embeds import Embed
     from ..file import File
     from ..mentions import AllowedMentions
+    from ..types.snowflake import Snowflake as SnowflakeAlias
     from ..types.webhook import Webhook as WebhookPayload
 
-    try:
+    with contextlib.suppress(ModuleNotFoundError):
         from requests import Response, Session
-    except ModuleNotFoundError:
-        pass
+
 
 MISSING = utils.MISSING
 
@@ -71,7 +73,10 @@ class DeferredLock:
 
 class WebhookAdapter:
     def __init__(self) -> None:
-        self._locks: Dict[Any, threading.Lock] = {}
+        self._locks: WeakValueDictionary[
+            Tuple[Optional[SnowflakeAlias], Optional[str]],
+            threading.Lock,
+        ] = WeakValueDictionary()
 
     def request(
         self,
@@ -85,7 +90,8 @@ class WebhookAdapter:
         auth_token: Optional[str] = None,
         params: Optional[Dict[str, Any]] = None,
     ) -> Any:
-        headers: Dict[str, str] = {}
+        # always ensure our user agent is being used
+        headers: Dict[str, str] = {"User-Agent": _USER_AGENT}
         files = files or []
         to_send: Optional[Union[str, Dict[str, Any]]] = None
         bucket = (route.webhook_id, route.webhook_token)
@@ -177,10 +183,11 @@ class WebhookAdapter:
 
                         if response.status_code == 403:
                             raise Forbidden(response, data)
-                        elif response.status_code == 404:
+
+                        if response.status_code == 404:
                             raise NotFound(response, data)
-                        else:
-                            raise HTTPException(response, data)
+
+                        raise HTTPException(response, data)
 
                 except OSError as e:
                     if attempt < 4 and e.errno in (54, 10054):
@@ -303,7 +310,11 @@ class WebhookAdapter:
         payload: Optional[Dict[str, Any]] = None,
         multipart: Optional[List[Dict[str, Any]]] = None,
         files: Optional[List[File]] = None,
+        thread_id: Optional[int] = None,
     ):
+        params = {}
+        if thread_id:
+            params["thread_id"] = thread_id
         route = Route(
             "PATCH",
             "/webhooks/{webhook_id}/{webhook_token}/messages/{message_id}",
@@ -311,7 +322,9 @@ class WebhookAdapter:
             webhook_token=token,
             message_id=message_id,
         )
-        return self.request(route, session, payload=payload, multipart=multipart, files=files)
+        return self.request(
+            route, session, payload=payload, multipart=multipart, files=files, params=params
+        )
 
     def delete_webhook_message(
         self,
@@ -820,8 +833,8 @@ class SyncWebhook(BaseWebhook):
         embeds: List[Embed] = MISSING,
         allowed_mentions: AllowedMentions = MISSING,
         wait: Literal[True],
-    ) -> SyncWebhookMessage:
-        ...
+        thread_name: Optional[str] = None,
+    ) -> SyncWebhookMessage: ...
 
     @overload
     def send(
@@ -837,8 +850,8 @@ class SyncWebhook(BaseWebhook):
         embeds: List[Embed] = MISSING,
         allowed_mentions: AllowedMentions = MISSING,
         wait: Literal[False] = ...,
-    ) -> None:
-        ...
+        thread_name: Optional[str] = None,
+    ) -> None: ...
 
     def send(
         self,
@@ -854,6 +867,7 @@ class SyncWebhook(BaseWebhook):
         allowed_mentions: AllowedMentions = MISSING,
         thread: Snowflake = MISSING,
         wait: bool = False,
+        thread_name: Optional[str] = None,
     ) -> Optional[SyncWebhookMessage]:
         """Sends a message using the webhook.
 
@@ -903,6 +917,11 @@ class SyncWebhook(BaseWebhook):
 
             .. versionadded:: 2.0
 
+        thread_name:
+            Name of thread to create (requires the webhook channel to be a forum or media channel).
+
+            .. versionadded:: 3.0
+
         Raises
         ------
         HTTPException
@@ -930,8 +949,6 @@ class SyncWebhook(BaseWebhook):
         previous_mentions: Optional[AllowedMentions] = getattr(
             self._state, "allowed_mentions", None
         )
-        if content is None:
-            content = MISSING
 
         params = handle_message_parameters(
             content=content,
@@ -944,11 +961,9 @@ class SyncWebhook(BaseWebhook):
             embeds=embeds,
             allowed_mentions=allowed_mentions,
             previous_allowed_mentions=previous_mentions,
+            thread_name=thread_name,
         )
         adapter: WebhookAdapter = _get_webhook_adapter()
-        thread_id: Optional[int] = None
-        if thread is not MISSING:
-            thread_id = thread.id
 
         data = adapter.execute_webhook(
             self.id,
@@ -957,11 +972,12 @@ class SyncWebhook(BaseWebhook):
             payload=params.payload,
             multipart=params.multipart,
             files=params.files,
-            thread_id=thread_id,
+            thread_id=thread.id if thread else None,
             wait=wait,
         )
         if wait:
             return self._create_message(data)
+        return None
 
     def fetch_message(self, id: int, /) -> SyncWebhookMessage:
         """Retrieves a single :class:`~nextcord.SyncWebhookMessage` owned by this webhook.
@@ -1013,6 +1029,7 @@ class SyncWebhook(BaseWebhook):
         files: List[File] = MISSING,
         attachments: List[Attachment] = MISSING,
         allowed_mentions: Optional[AllowedMentions] = None,
+        thread: Snowflake = MISSING,
     ) -> SyncWebhookMessage:
         """Edits a message owned by this webhook.
 
@@ -1042,6 +1059,10 @@ class SyncWebhook(BaseWebhook):
         allowed_mentions: :class:`AllowedMentions`
             Controls the mentions being processed in this message.
             See :meth:`.abc.Messageable.send` for more information.
+        thread: :class:`~nextcord.abc.Snowflake`
+            The thread that the message to be edited is in.
+
+            .. versionadded:: 3.0
 
         Raises
         ------
@@ -1074,6 +1095,9 @@ class SyncWebhook(BaseWebhook):
             previous_allowed_mentions=previous_mentions,
         )
         adapter: WebhookAdapter = _get_webhook_adapter()
+        thread_id: Optional[int] = None
+        if thread is not MISSING:
+            thread_id = thread.id
         data = adapter.edit_webhook_message(
             self.id,
             self.token,
@@ -1082,6 +1106,7 @@ class SyncWebhook(BaseWebhook):
             payload=params.payload,
             multipart=params.multipart,
             files=params.files,
+            thread_id=thread_id,
         )
         return self._create_message(data)
 
